/***********************************************************
* Rocks'n'Diamonds -- McDuffin Strikes Back!               *
*----------------------------------------------------------*
* (c) 1995-2006 Artsoft Entertainment                      *
*               Holger Schemel                             *
*               Detmolder Strasse 189                      *
*               33604 Bielefeld                            *
*               Germany                                    *
*               e-mail: info@artsoft.org                   *
*----------------------------------------------------------*
* conf_e2g.c                                               *
***********************************************************/

/* ----- this file was automatically generated -- do not edit by hand ----- */

#ifndef CONF_E2G_C
#define CONF_E2G_C

/* values for element/graphics mapping configuration (normal) */

static struct
{
  int element;
  int action;
  int direction;
  boolean crumbled;

  int graphic;
}
element_to_graphic[] =
{
  {
    EL_BD_WALL,				-1, -1, FALSE,
    IMG_BD_WALL
  },
  {
    EL_BD_ROCK,				-1, -1, FALSE,
    IMG_BD_ROCK
  },
  {
    EL_BD_ROCK,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_BD_ROCK_MOVING_LEFT
  },
  {
    EL_BD_ROCK,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_BD_ROCK_MOVING_RIGHT
  },
  {
    EL_BD_ROCK,				ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_BD_ROCK_PUSHING_LEFT
  },
  {
    EL_BD_ROCK,				ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_BD_ROCK_PUSHING_RIGHT
  },
  {
    EL_BD_DIAMOND,			-1, -1, FALSE,
    IMG_BD_DIAMOND
  },
  {
    EL_BD_DIAMOND,			ACTION_MOVING, -1, FALSE,
    IMG_BD_DIAMOND_MOVING
  },
  {
    EL_BD_DIAMOND,			ACTION_FALLING, -1, FALSE,
    IMG_BD_DIAMOND_FALLING
  },
  {
    EL_BD_MAGIC_WALL,			-1, -1, FALSE,
    IMG_BD_MAGIC_WALL
  },
  {
    EL_BD_MAGIC_WALL_ACTIVE,		-1, -1, FALSE,
    IMG_BD_MAGIC_WALL_ACTIVE
  },
  {
    EL_BD_MAGIC_WALL,			ACTION_ACTIVE, -1, FALSE,
    IMG_BD_MAGIC_WALL_ACTIVE
  },
  {
    EL_BD_MAGIC_WALL_FILLING,		-1, -1, FALSE,
    IMG_BD_MAGIC_WALL_FILLING
  },
  {
    EL_BD_MAGIC_WALL,			ACTION_FILLING, -1, FALSE,
    IMG_BD_MAGIC_WALL_FILLING
  },
  {
    EL_BD_MAGIC_WALL_FULL,		-1, -1, FALSE,
    IMG_BD_MAGIC_WALL_FULL
  },
  {
    EL_BD_MAGIC_WALL_EMPTYING,		-1, -1, FALSE,
    IMG_BD_MAGIC_WALL_EMPTYING
  },
  {
    EL_BD_MAGIC_WALL,			ACTION_EMPTYING, -1, FALSE,
    IMG_BD_MAGIC_WALL_EMPTYING
  },
  {
    EL_BD_MAGIC_WALL_DEAD,		-1, -1, FALSE,
    IMG_BD_MAGIC_WALL_DEAD
  },
  {
    EL_BD_AMOEBA,			-1, -1, FALSE,
    IMG_BD_AMOEBA
  },
  {
    EL_BD_BUTTERFLY,			-1, -1, FALSE,
    IMG_BD_BUTTERFLY
  },
  {
    EL_BD_BUTTERFLY_RIGHT,		-1, -1, FALSE,
    IMG_BD_BUTTERFLY_RIGHT
  },
  {
    EL_BD_BUTTERFLY,			-1, MV_BIT_RIGHT, FALSE,
    IMG_BD_BUTTERFLY_RIGHT
  },
  {
    EL_BD_BUTTERFLY_UP,			-1, -1, FALSE,
    IMG_BD_BUTTERFLY_UP
  },
  {
    EL_BD_BUTTERFLY,			-1, MV_BIT_UP, FALSE,
    IMG_BD_BUTTERFLY_UP
  },
  {
    EL_BD_BUTTERFLY_LEFT,		-1, -1, FALSE,
    IMG_BD_BUTTERFLY_LEFT
  },
  {
    EL_BD_BUTTERFLY,			-1, MV_BIT_LEFT, FALSE,
    IMG_BD_BUTTERFLY_LEFT
  },
  {
    EL_BD_BUTTERFLY_DOWN,		-1, -1, FALSE,
    IMG_BD_BUTTERFLY_DOWN
  },
  {
    EL_BD_BUTTERFLY,			-1, MV_BIT_DOWN, FALSE,
    IMG_BD_BUTTERFLY_DOWN
  },
  {
    EL_BD_FIREFLY,			-1, -1, FALSE,
    IMG_BD_FIREFLY
  },
  {
    EL_BD_FIREFLY_RIGHT,		-1, -1, FALSE,
    IMG_BD_FIREFLY_RIGHT
  },
  {
    EL_BD_FIREFLY,			-1, MV_BIT_RIGHT, FALSE,
    IMG_BD_FIREFLY_RIGHT
  },
  {
    EL_BD_FIREFLY_UP,			-1, -1, FALSE,
    IMG_BD_FIREFLY_UP
  },
  {
    EL_BD_FIREFLY,			-1, MV_BIT_UP, FALSE,
    IMG_BD_FIREFLY_UP
  },
  {
    EL_BD_FIREFLY_LEFT,			-1, -1, FALSE,
    IMG_BD_FIREFLY_LEFT
  },
  {
    EL_BD_FIREFLY,			-1, MV_BIT_LEFT, FALSE,
    IMG_BD_FIREFLY_LEFT
  },
  {
    EL_BD_FIREFLY_DOWN,			-1, -1, FALSE,
    IMG_BD_FIREFLY_DOWN
  },
  {
    EL_BD_FIREFLY,			-1, MV_BIT_DOWN, FALSE,
    IMG_BD_FIREFLY_DOWN
  },
  {
    EL_SP_DEFAULT,			ACTION_EXPLODING, -1, FALSE,
    IMG_SP_DEFAULT_EXPLODING
  },
  {
    EL_SP_ZONK,				-1, -1, FALSE,
    IMG_SP_ZONK
  },
  {
    EL_SP_ZONK,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_SP_ZONK_MOVING_LEFT
  },
  {
    EL_SP_ZONK,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_SP_ZONK_MOVING_RIGHT
  },
  {
    EL_SP_ZONK,				ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_SP_ZONK_PUSHING_LEFT
  },
  {
    EL_SP_ZONK,				ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_SP_ZONK_PUSHING_RIGHT
  },
  {
    EL_SP_BASE,				-1, -1, FALSE,
    IMG_SP_BASE
  },
  {
    EL_SP_BASE,				ACTION_DIGGING, -1, FALSE,
    IMG_SP_BASE_DIGGING
  },
  {
    EL_SP_BASE,				ACTION_SNAPPING, -1, FALSE,
    IMG_SP_BASE_SNAPPING
  },
  {
    EL_SP_MURPHY,			-1, -1, FALSE,
    IMG_SP_MURPHY
  },
  {
    EL_SP_MURPHY,			ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_SP_MURPHY_MOVING_LEFT
  },
  {
    EL_SP_MURPHY,			ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_SP_MURPHY_MOVING_RIGHT
  },
  {
    EL_SP_MURPHY,			ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_SP_MURPHY_DIGGING_LEFT
  },
  {
    EL_SP_MURPHY,			ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_SP_MURPHY_DIGGING_RIGHT
  },
  {
    EL_SP_MURPHY,			ACTION_COLLECTING, MV_BIT_LEFT, FALSE,
    IMG_SP_MURPHY_COLLECTING_LEFT
  },
  {
    EL_SP_MURPHY,			ACTION_COLLECTING, MV_BIT_RIGHT, FALSE,
    IMG_SP_MURPHY_COLLECTING_RIGHT
  },
  {
    EL_SP_MURPHY,			ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_SP_MURPHY_PUSHING_LEFT
  },
  {
    EL_SP_MURPHY,			ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_SP_MURPHY_PUSHING_RIGHT
  },
  {
    EL_SP_MURPHY,			ACTION_SNAPPING, MV_BIT_LEFT, FALSE,
    IMG_SP_MURPHY_SNAPPING_LEFT
  },
  {
    EL_SP_MURPHY,			ACTION_SNAPPING, MV_BIT_RIGHT, FALSE,
    IMG_SP_MURPHY_SNAPPING_RIGHT
  },
  {
    EL_SP_MURPHY,			ACTION_SNAPPING, MV_BIT_UP, FALSE,
    IMG_SP_MURPHY_SNAPPING_UP
  },
  {
    EL_SP_MURPHY,			ACTION_SNAPPING, MV_BIT_DOWN, FALSE,
    IMG_SP_MURPHY_SNAPPING_DOWN
  },
  {
    EL_SP_MURPHY,			ACTION_BORING, -1, FALSE,
    IMG_SP_MURPHY_BORING
  },
  {
    EL_SP_MURPHY,			ACTION_BORING_1, -1, FALSE,
    IMG_SP_MURPHY_BORING_1
  },
  {
    EL_SP_MURPHY,			ACTION_SLEEPING, MV_BIT_LEFT, FALSE,
    IMG_SP_MURPHY_SLEEPING_LEFT
  },
  {
    EL_SP_MURPHY,			ACTION_SLEEPING, MV_BIT_RIGHT, FALSE,
    IMG_SP_MURPHY_SLEEPING_RIGHT
  },
  {
    EL_SP_MURPHY_CLONE,			-1, -1, FALSE,
    IMG_SP_MURPHY_CLONE
  },
  {
    EL_SP_INFOTRON,			-1, -1, FALSE,
    IMG_SP_INFOTRON
  },
  {
    EL_SP_INFOTRON,			ACTION_COLLECTING, -1, FALSE,
    IMG_SP_INFOTRON_COLLECTING
  },
  {
    EL_SP_CHIP_SINGLE,			-1, -1, FALSE,
    IMG_SP_CHIP_SINGLE
  },
  {
    EL_SP_CHIP_LEFT,			-1, -1, FALSE,
    IMG_SP_CHIP_LEFT
  },
  {
    EL_SP_CHIP_RIGHT,			-1, -1, FALSE,
    IMG_SP_CHIP_RIGHT
  },
  {
    EL_SP_CHIP_TOP,			-1, -1, FALSE,
    IMG_SP_CHIP_TOP
  },
  {
    EL_SP_CHIP_BOTTOM,			-1, -1, FALSE,
    IMG_SP_CHIP_BOTTOM
  },
  {
    EL_SP_HARDWARE_GRAY,		-1, -1, FALSE,
    IMG_SP_HARDWARE_GRAY
  },
  {
    EL_SP_HARDWARE_GREEN,		-1, -1, FALSE,
    IMG_SP_HARDWARE_GREEN
  },
  {
    EL_SP_HARDWARE_BLUE,		-1, -1, FALSE,
    IMG_SP_HARDWARE_BLUE
  },
  {
    EL_SP_HARDWARE_RED,			-1, -1, FALSE,
    IMG_SP_HARDWARE_RED
  },
  {
    EL_SP_HARDWARE_YELLOW,		-1, -1, FALSE,
    IMG_SP_HARDWARE_YELLOW
  },
  {
    EL_SP_EXIT_CLOSED,			-1, -1, FALSE,
    IMG_SP_EXIT_CLOSED
  },
  {
    EL_SP_EXIT_OPENING,			-1, -1, FALSE,
    IMG_SP_EXIT_OPENING
  },
  {
    EL_SP_EXIT_OPEN,			-1, -1, FALSE,
    IMG_SP_EXIT_OPEN
  },
  {
    EL_SP_EXIT_CLOSING,			-1, -1, FALSE,
    IMG_SP_EXIT_CLOSING
  },
  {
    EL_SP_DISK_ORANGE,			-1, -1, FALSE,
    IMG_SP_DISK_ORANGE
  },
  {
    EL_SP_DISK_YELLOW,			-1, -1, FALSE,
    IMG_SP_DISK_YELLOW
  },
  {
    EL_SP_DISK_RED,			-1, -1, FALSE,
    IMG_SP_DISK_RED
  },
  {
    EL_SP_DISK_RED,			ACTION_COLLECTING, -1, FALSE,
    IMG_SP_DISK_RED_COLLECTING
  },
  {
    EL_SP_DISK_RED_ACTIVE,		-1, -1, FALSE,
    IMG_SP_DISK_RED_ACTIVE
  },
  {
    EL_SP_DISK_RED,			ACTION_ACTIVE, -1, FALSE,
    IMG_SP_DISK_RED_ACTIVE
  },
  {
    EL_SP_PORT_RIGHT,			-1, -1, FALSE,
    IMG_SP_PORT_RIGHT
  },
  {
    EL_SP_PORT_DOWN,			-1, -1, FALSE,
    IMG_SP_PORT_DOWN
  },
  {
    EL_SP_PORT_LEFT,			-1, -1, FALSE,
    IMG_SP_PORT_LEFT
  },
  {
    EL_SP_PORT_UP,			-1, -1, FALSE,
    IMG_SP_PORT_UP
  },
  {
    EL_SP_PORT_HORIZONTAL,		-1, -1, FALSE,
    IMG_SP_PORT_HORIZONTAL
  },
  {
    EL_SP_PORT_VERTICAL,		-1, -1, FALSE,
    IMG_SP_PORT_VERTICAL
  },
  {
    EL_SP_PORT_ANY,			-1, -1, FALSE,
    IMG_SP_PORT_ANY
  },
  {
    EL_SP_GRAVITY_PORT_RIGHT,		-1, -1, FALSE,
    IMG_SP_GRAVITY_PORT_RIGHT
  },
  {
    EL_SP_GRAVITY_PORT_DOWN,		-1, -1, FALSE,
    IMG_SP_GRAVITY_PORT_DOWN
  },
  {
    EL_SP_GRAVITY_PORT_LEFT,		-1, -1, FALSE,
    IMG_SP_GRAVITY_PORT_LEFT
  },
  {
    EL_SP_GRAVITY_PORT_UP,		-1, -1, FALSE,
    IMG_SP_GRAVITY_PORT_UP
  },
  {
    EL_SP_GRAVITY_ON_PORT_RIGHT,	-1, -1, FALSE,
    IMG_SP_GRAVITY_ON_PORT_RIGHT
  },
  {
    EL_SP_GRAVITY_ON_PORT_DOWN,		-1, -1, FALSE,
    IMG_SP_GRAVITY_ON_PORT_DOWN
  },
  {
    EL_SP_GRAVITY_ON_PORT_LEFT,		-1, -1, FALSE,
    IMG_SP_GRAVITY_ON_PORT_LEFT
  },
  {
    EL_SP_GRAVITY_ON_PORT_UP,		-1, -1, FALSE,
    IMG_SP_GRAVITY_ON_PORT_UP
  },
  {
    EL_SP_GRAVITY_OFF_PORT_RIGHT,	-1, -1, FALSE,
    IMG_SP_GRAVITY_OFF_PORT_RIGHT
  },
  {
    EL_SP_GRAVITY_OFF_PORT_DOWN,	-1, -1, FALSE,
    IMG_SP_GRAVITY_OFF_PORT_DOWN
  },
  {
    EL_SP_GRAVITY_OFF_PORT_LEFT,	-1, -1, FALSE,
    IMG_SP_GRAVITY_OFF_PORT_LEFT
  },
  {
    EL_SP_GRAVITY_OFF_PORT_UP,		-1, -1, FALSE,
    IMG_SP_GRAVITY_OFF_PORT_UP
  },
  {
    EL_SP_SNIKSNAK,			-1, -1, FALSE,
    IMG_SP_SNIKSNAK
  },
  {
    EL_SP_SNIKSNAK,			-1, MV_BIT_LEFT, FALSE,
    IMG_SP_SNIKSNAK_LEFT
  },
  {
    EL_SP_SNIKSNAK,			-1, MV_BIT_RIGHT, FALSE,
    IMG_SP_SNIKSNAK_RIGHT
  },
  {
    EL_SP_SNIKSNAK,			-1, MV_BIT_UP, FALSE,
    IMG_SP_SNIKSNAK_UP
  },
  {
    EL_SP_SNIKSNAK,			-1, MV_BIT_DOWN, FALSE,
    IMG_SP_SNIKSNAK_DOWN
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_LEFT, MV_BIT_UP, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_UP
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_LEFT, MV_BIT_DOWN, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_LEFT_DOWN
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_RIGHT, MV_BIT_UP, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_UP
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_RIGHT, MV_BIT_DOWN, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_RIGHT_DOWN
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_UP, MV_BIT_LEFT, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_UP_LEFT
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_UP, MV_BIT_RIGHT, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_UP_RIGHT
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_DOWN, MV_BIT_LEFT, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_LEFT
  },
  {
    EL_SP_SNIKSNAK,			ACTION_TURNING_FROM_DOWN, MV_BIT_RIGHT, FALSE,
    IMG_SP_SNIKSNAK_TURNING_FROM_DOWN_RIGHT
  },
  {
    EL_SP_ELECTRON,			-1, -1, FALSE,
    IMG_SP_ELECTRON
  },
  {
    EL_SP_ELECTRON,			ACTION_EXPLODING, -1, FALSE,
    IMG_SP_ELECTRON_EXPLODING
  },
  {
    EL_SP_TERMINAL,			-1, -1, FALSE,
    IMG_SP_TERMINAL
  },
  {
    EL_SP_TERMINAL_ACTIVE,		-1, -1, FALSE,
    IMG_SP_TERMINAL_ACTIVE
  },
  {
    EL_SP_TERMINAL,			ACTION_ACTIVE, -1, FALSE,
    IMG_SP_TERMINAL_ACTIVE
  },
  {
    EL_SP_BUGGY_BASE,			-1, -1, FALSE,
    IMG_SP_BUGGY_BASE
  },
  {
    EL_SP_BUGGY_BASE_ACTIVATING,	-1, -1, FALSE,
    IMG_SP_BUGGY_BASE_ACTIVATING
  },
  {
    EL_SP_BUGGY_BASE,			ACTION_ACTIVATING, -1, FALSE,
    IMG_SP_BUGGY_BASE_ACTIVATING
  },
  {
    EL_SP_BUGGY_BASE_ACTIVE,		-1, -1, FALSE,
    IMG_SP_BUGGY_BASE_ACTIVE
  },
  {
    EL_SP_BUGGY_BASE,			ACTION_ACTIVE, -1, FALSE,
    IMG_SP_BUGGY_BASE_ACTIVE
  },
  {
    EL_SP_HARDWARE_BASE_1,		-1, -1, FALSE,
    IMG_SP_HARDWARE_BASE_1
  },
  {
    EL_SP_HARDWARE_BASE_2,		-1, -1, FALSE,
    IMG_SP_HARDWARE_BASE_2
  },
  {
    EL_SP_HARDWARE_BASE_3,		-1, -1, FALSE,
    IMG_SP_HARDWARE_BASE_3
  },
  {
    EL_SP_HARDWARE_BASE_4,		-1, -1, FALSE,
    IMG_SP_HARDWARE_BASE_4
  },
  {
    EL_SP_HARDWARE_BASE_5,		-1, -1, FALSE,
    IMG_SP_HARDWARE_BASE_5
  },
  {
    EL_SP_HARDWARE_BASE_6,		-1, -1, FALSE,
    IMG_SP_HARDWARE_BASE_6
  },
  {
    EL_SOKOBAN_OBJECT,			-1, -1, FALSE,
    IMG_SOKOBAN_OBJECT
  },
  {
    EL_SOKOBAN_FIELD_EMPTY,		-1, -1, FALSE,
    IMG_SOKOBAN_FIELD_EMPTY
  },
  {
    EL_SOKOBAN_FIELD_FULL,		-1, -1, FALSE,
    IMG_SOKOBAN_FIELD_FULL
  },
  {
    EL_SOKOBAN_FIELD_PLAYER,		-1, -1, FALSE,
    IMG_SOKOBAN_FIELD_PLAYER
  },
  {
    EL_EMPTY_SPACE,			-1, -1, FALSE,
    IMG_EMPTY_SPACE
  },
  {
    EL_SAND,				-1, -1, FALSE,
    IMG_SAND
  },
  {
    EL_SAND,				-1, -1, TRUE,
    IMG_SAND_CRUMBLED
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_SAND_DIGGING_LEFT
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_SAND_DIGGING_RIGHT
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_SAND_DIGGING_UP
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_SAND_DIGGING_DOWN
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_LEFT, TRUE,
    IMG_SAND_DIGGING_LEFT_CRUMBLED
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_RIGHT, TRUE,
    IMG_SAND_DIGGING_RIGHT_CRUMBLED
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_UP, TRUE,
    IMG_SAND_DIGGING_UP_CRUMBLED
  },
  {
    EL_SAND,				ACTION_DIGGING, MV_BIT_DOWN, TRUE,
    IMG_SAND_DIGGING_DOWN_CRUMBLED
  },
  {
    EL_WALL,				-1, -1, FALSE,
    IMG_WALL
  },
  {
    EL_WALL_SLIPPERY,			-1, -1, FALSE,
    IMG_WALL_SLIPPERY
  },
  {
    EL_STEELWALL,			-1, -1, FALSE,
    IMG_STEELWALL
  },
  {
    EL_ROCK,				-1, -1, FALSE,
    IMG_ROCK
  },
  {
    EL_ROCK,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_ROCK_MOVING_LEFT
  },
  {
    EL_ROCK,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_ROCK_MOVING_RIGHT
  },
  {
    EL_ROCK,				ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_ROCK_PUSHING_LEFT
  },
  {
    EL_ROCK,				ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_ROCK_PUSHING_RIGHT
  },
  {
    EL_EMERALD,				-1, -1, FALSE,
    IMG_EMERALD
  },
  {
    EL_EMERALD,				ACTION_MOVING, -1, FALSE,
    IMG_EMERALD_MOVING
  },
  {
    EL_EMERALD,				ACTION_FALLING, -1, FALSE,
    IMG_EMERALD_FALLING
  },
  {
    EL_EMERALD,				ACTION_COLLECTING, -1, FALSE,
    IMG_EMERALD_COLLECTING
  },
  {
    EL_DIAMOND,				-1, -1, FALSE,
    IMG_DIAMOND
  },
  {
    EL_DIAMOND,				ACTION_MOVING, -1, FALSE,
    IMG_DIAMOND_MOVING
  },
  {
    EL_DIAMOND,				ACTION_FALLING, -1, FALSE,
    IMG_DIAMOND_FALLING
  },
  {
    EL_DIAMOND,				ACTION_COLLECTING, -1, FALSE,
    IMG_DIAMOND_COLLECTING
  },
  {
    EL_BOMB,				-1, -1, FALSE,
    IMG_BOMB
  },
  {
    EL_NUT,				-1, -1, FALSE,
    IMG_NUT
  },
  {
    EL_NUT_BREAKING,			-1, -1, FALSE,
    IMG_NUT_BREAKING
  },
  {
    EL_NUT,				ACTION_BREAKING, -1, FALSE,
    IMG_NUT_BREAKING
  },
  {
    EL_DYNAMITE,			-1, -1, FALSE,
    IMG_DYNAMITE
  },
  {
    EL_DYNAMITE_ACTIVE,			-1, -1, FALSE,
    IMG_DYNAMITE_ACTIVE
  },
  {
    EL_DYNAMITE,			ACTION_ACTIVE, -1, FALSE,
    IMG_DYNAMITE_ACTIVE
  },
  {
    EL_EM_DYNAMITE,			-1, -1, FALSE,
    IMG_EM_DYNAMITE
  },
  {
    EL_EM_DYNAMITE_ACTIVE,		-1, -1, FALSE,
    IMG_EM_DYNAMITE_ACTIVE
  },
  {
    EL_EM_DYNAMITE,			ACTION_ACTIVE, -1, FALSE,
    IMG_EM_DYNAMITE_ACTIVE
  },
  {
    EL_WALL_EMERALD,			-1, -1, FALSE,
    IMG_WALL_EMERALD
  },
  {
    EL_WALL_DIAMOND,			-1, -1, FALSE,
    IMG_WALL_DIAMOND
  },
  {
    EL_BUG,				-1, -1, FALSE,
    IMG_BUG
  },
  {
    EL_BUG_RIGHT,			-1, -1, FALSE,
    IMG_BUG_RIGHT
  },
  {
    EL_BUG,				-1, MV_BIT_RIGHT, FALSE,
    IMG_BUG_RIGHT
  },
  {
    EL_BUG_UP,				-1, -1, FALSE,
    IMG_BUG_UP
  },
  {
    EL_BUG,				-1, MV_BIT_UP, FALSE,
    IMG_BUG_UP
  },
  {
    EL_BUG_LEFT,			-1, -1, FALSE,
    IMG_BUG_LEFT
  },
  {
    EL_BUG,				-1, MV_BIT_LEFT, FALSE,
    IMG_BUG_LEFT
  },
  {
    EL_BUG_DOWN,			-1, -1, FALSE,
    IMG_BUG_DOWN
  },
  {
    EL_BUG,				-1, MV_BIT_DOWN, FALSE,
    IMG_BUG_DOWN
  },
  {
    EL_BUG,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_BUG_MOVING_RIGHT
  },
  {
    EL_BUG,				ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_BUG_MOVING_UP
  },
  {
    EL_BUG,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_BUG_MOVING_LEFT
  },
  {
    EL_BUG,				ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_BUG_MOVING_DOWN
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_RIGHT, MV_BIT_UP, FALSE,
    IMG_BUG_TURNING_FROM_RIGHT_UP
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_UP, MV_BIT_LEFT, FALSE,
    IMG_BUG_TURNING_FROM_UP_LEFT
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_LEFT, MV_BIT_DOWN, FALSE,
    IMG_BUG_TURNING_FROM_LEFT_DOWN
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_DOWN, MV_BIT_RIGHT, FALSE,
    IMG_BUG_TURNING_FROM_DOWN_RIGHT
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_RIGHT, MV_BIT_DOWN, FALSE,
    IMG_BUG_TURNING_FROM_RIGHT_DOWN
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_UP, MV_BIT_RIGHT, FALSE,
    IMG_BUG_TURNING_FROM_UP_RIGHT
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_LEFT, MV_BIT_UP, FALSE,
    IMG_BUG_TURNING_FROM_LEFT_UP
  },
  {
    EL_BUG,				ACTION_TURNING_FROM_DOWN, MV_BIT_LEFT, FALSE,
    IMG_BUG_TURNING_FROM_DOWN_LEFT
  },
  {
    EL_SPACESHIP,			-1, -1, FALSE,
    IMG_SPACESHIP
  },
  {
    EL_SPACESHIP_RIGHT,			-1, -1, FALSE,
    IMG_SPACESHIP_RIGHT
  },
  {
    EL_SPACESHIP,			-1, MV_BIT_RIGHT, FALSE,
    IMG_SPACESHIP_RIGHT
  },
  {
    EL_SPACESHIP_UP,			-1, -1, FALSE,
    IMG_SPACESHIP_UP
  },
  {
    EL_SPACESHIP,			-1, MV_BIT_UP, FALSE,
    IMG_SPACESHIP_UP
  },
  {
    EL_SPACESHIP_LEFT,			-1, -1, FALSE,
    IMG_SPACESHIP_LEFT
  },
  {
    EL_SPACESHIP,			-1, MV_BIT_LEFT, FALSE,
    IMG_SPACESHIP_LEFT
  },
  {
    EL_SPACESHIP_DOWN,			-1, -1, FALSE,
    IMG_SPACESHIP_DOWN
  },
  {
    EL_SPACESHIP,			-1, MV_BIT_DOWN, FALSE,
    IMG_SPACESHIP_DOWN
  },
  {
    EL_SPACESHIP,			ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_SPACESHIP_MOVING_RIGHT
  },
  {
    EL_SPACESHIP,			ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_SPACESHIP_MOVING_UP
  },
  {
    EL_SPACESHIP,			ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_SPACESHIP_MOVING_LEFT
  },
  {
    EL_SPACESHIP,			ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_SPACESHIP_MOVING_DOWN
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_RIGHT, MV_BIT_UP, FALSE,
    IMG_SPACESHIP_TURNING_FROM_RIGHT_UP
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_UP, MV_BIT_LEFT, FALSE,
    IMG_SPACESHIP_TURNING_FROM_UP_LEFT
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_LEFT, MV_BIT_DOWN, FALSE,
    IMG_SPACESHIP_TURNING_FROM_LEFT_DOWN
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_DOWN, MV_BIT_RIGHT, FALSE,
    IMG_SPACESHIP_TURNING_FROM_DOWN_RIGHT
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_RIGHT, MV_BIT_DOWN, FALSE,
    IMG_SPACESHIP_TURNING_FROM_RIGHT_DOWN
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_UP, MV_BIT_RIGHT, FALSE,
    IMG_SPACESHIP_TURNING_FROM_UP_RIGHT
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_LEFT, MV_BIT_UP, FALSE,
    IMG_SPACESHIP_TURNING_FROM_LEFT_UP
  },
  {
    EL_SPACESHIP,			ACTION_TURNING_FROM_DOWN, MV_BIT_LEFT, FALSE,
    IMG_SPACESHIP_TURNING_FROM_DOWN_LEFT
  },
  {
    EL_YAMYAM,				-1, -1, FALSE,
    IMG_YAMYAM
  },
  {
    EL_YAMYAM_LEFT,			-1, -1, FALSE,
    IMG_YAMYAM_LEFT
  },
  {
    EL_YAMYAM,				-1, MV_BIT_LEFT, FALSE,
    IMG_YAMYAM_LEFT
  },
  {
    EL_YAMYAM_RIGHT,			-1, -1, FALSE,
    IMG_YAMYAM_RIGHT
  },
  {
    EL_YAMYAM,				-1, MV_BIT_RIGHT, FALSE,
    IMG_YAMYAM_RIGHT
  },
  {
    EL_YAMYAM_UP,			-1, -1, FALSE,
    IMG_YAMYAM_UP
  },
  {
    EL_YAMYAM,				-1, MV_BIT_UP, FALSE,
    IMG_YAMYAM_UP
  },
  {
    EL_YAMYAM_DOWN,			-1, -1, FALSE,
    IMG_YAMYAM_DOWN
  },
  {
    EL_YAMYAM,				-1, MV_BIT_DOWN, FALSE,
    IMG_YAMYAM_DOWN
  },
  {
    EL_YAMYAM,				ACTION_MOVING, -1, FALSE,
    IMG_YAMYAM_MOVING
  },
  {
    EL_ROBOT,				-1, -1, FALSE,
    IMG_ROBOT
  },
  {
    EL_ROBOT,				ACTION_MOVING, -1, FALSE,
    IMG_ROBOT_MOVING
  },
  {
    EL_ROBOT_WHEEL,			-1, -1, FALSE,
    IMG_ROBOT_WHEEL
  },
  {
    EL_ROBOT_WHEEL_ACTIVE,		-1, -1, FALSE,
    IMG_ROBOT_WHEEL_ACTIVE
  },
  {
    EL_ROBOT_WHEEL,			ACTION_ACTIVE, -1, FALSE,
    IMG_ROBOT_WHEEL_ACTIVE
  },
  {
    EL_MAGIC_WALL,			-1, -1, FALSE,
    IMG_MAGIC_WALL
  },
  {
    EL_MAGIC_WALL_ACTIVE,		-1, -1, FALSE,
    IMG_MAGIC_WALL_ACTIVE
  },
  {
    EL_MAGIC_WALL,			ACTION_ACTIVE, -1, FALSE,
    IMG_MAGIC_WALL_ACTIVE
  },
  {
    EL_MAGIC_WALL_FILLING,		-1, -1, FALSE,
    IMG_MAGIC_WALL_FILLING
  },
  {
    EL_MAGIC_WALL,			ACTION_FILLING, -1, FALSE,
    IMG_MAGIC_WALL_FILLING
  },
  {
    EL_MAGIC_WALL_FULL,			-1, -1, FALSE,
    IMG_MAGIC_WALL_FULL
  },
  {
    EL_MAGIC_WALL_EMPTYING,		-1, -1, FALSE,
    IMG_MAGIC_WALL_EMPTYING
  },
  {
    EL_MAGIC_WALL,			ACTION_EMPTYING, -1, FALSE,
    IMG_MAGIC_WALL_EMPTYING
  },
  {
    EL_MAGIC_WALL_DEAD,			-1, -1, FALSE,
    IMG_MAGIC_WALL_DEAD
  },
  {
    EL_QUICKSAND_EMPTY,			-1, -1, FALSE,
    IMG_QUICKSAND_EMPTY
  },
  {
    EL_QUICKSAND_FILLING,		-1, -1, FALSE,
    IMG_QUICKSAND_FILLING
  },
  {
    EL_QUICKSAND_FULL,			-1, -1, FALSE,
    IMG_QUICKSAND_FULL
  },
  {
    EL_QUICKSAND_EMPTYING,		-1, -1, FALSE,
    IMG_QUICKSAND_EMPTYING
  },
  {
    EL_ACID_POOL_TOPLEFT,		-1, -1, FALSE,
    IMG_ACID_POOL_TOPLEFT
  },
  {
    EL_ACID_POOL_TOPRIGHT,		-1, -1, FALSE,
    IMG_ACID_POOL_TOPRIGHT
  },
  {
    EL_ACID_POOL_BOTTOMLEFT,		-1, -1, FALSE,
    IMG_ACID_POOL_BOTTOMLEFT
  },
  {
    EL_ACID_POOL_BOTTOM,		-1, -1, FALSE,
    IMG_ACID_POOL_BOTTOM
  },
  {
    EL_ACID_POOL_BOTTOMRIGHT,		-1, -1, FALSE,
    IMG_ACID_POOL_BOTTOMRIGHT
  },
  {
    EL_ACID,				-1, -1, FALSE,
    IMG_ACID
  },
  {
    EL_ACID_SPLASH_LEFT,		-1, -1, FALSE,
    IMG_ACID_SPLASH_LEFT
  },
  {
    EL_ACID_SPLASH_RIGHT,		-1, -1, FALSE,
    IMG_ACID_SPLASH_RIGHT
  },
  {
    EL_AMOEBA_DROP,			-1, -1, FALSE,
    IMG_AMOEBA_DROP
  },
  {
    EL_AMOEBA_GROWING,			-1, -1, FALSE,
    IMG_AMOEBA_GROWING
  },
  {
    EL_AMOEBA,				ACTION_GROWING, -1, FALSE,
    IMG_AMOEBA_GROWING
  },
  {
    EL_AMOEBA_SHRINKING,		-1, -1, FALSE,
    IMG_AMOEBA_SHRINKING
  },
  {
    EL_AMOEBA,				ACTION_SHRINKING, -1, FALSE,
    IMG_AMOEBA_SHRINKING
  },
  {
    EL_AMOEBA_WET,			-1, -1, FALSE,
    IMG_AMOEBA_WET
  },
  {
    EL_AMOEBA_DROPPING,			-1, -1, FALSE,
    IMG_AMOEBA_DROPPING
  },
  {
    EL_AMOEBA,				ACTION_DROPPING, -1, FALSE,
    IMG_AMOEBA_DROPPING
  },
  {
    EL_AMOEBA_DRY,			-1, -1, FALSE,
    IMG_AMOEBA_DRY
  },
  {
    EL_AMOEBA_FULL,			-1, -1, FALSE,
    IMG_AMOEBA_FULL
  },
  {
    EL_AMOEBA_DEAD,			-1, -1, FALSE,
    IMG_AMOEBA_DEAD
  },
  {
    EL_EM_KEY_1,			-1, -1, FALSE,
    IMG_EM_KEY_1
  },
  {
    EL_EM_KEY_2,			-1, -1, FALSE,
    IMG_EM_KEY_2
  },
  {
    EL_EM_KEY_3,			-1, -1, FALSE,
    IMG_EM_KEY_3
  },
  {
    EL_EM_KEY_4,			-1, -1, FALSE,
    IMG_EM_KEY_4
  },
  {
    EL_EM_GATE_1,			-1, -1, FALSE,
    IMG_EM_GATE_1
  },
  {
    EL_EM_GATE_2,			-1, -1, FALSE,
    IMG_EM_GATE_2
  },
  {
    EL_EM_GATE_3,			-1, -1, FALSE,
    IMG_EM_GATE_3
  },
  {
    EL_EM_GATE_4,			-1, -1, FALSE,
    IMG_EM_GATE_4
  },
  {
    EL_EM_GATE_1_GRAY,			-1, -1, FALSE,
    IMG_EM_GATE_1_GRAY
  },
  {
    EL_EM_GATE_1_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EM_GATE_1_GRAY_ACTIVE
  },
  {
    EL_EM_GATE_1_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EM_GATE_1_GRAY_ACTIVE
  },
  {
    EL_EM_GATE_2_GRAY,			-1, -1, FALSE,
    IMG_EM_GATE_2_GRAY
  },
  {
    EL_EM_GATE_2_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EM_GATE_2_GRAY_ACTIVE
  },
  {
    EL_EM_GATE_2_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EM_GATE_2_GRAY_ACTIVE
  },
  {
    EL_EM_GATE_3_GRAY,			-1, -1, FALSE,
    IMG_EM_GATE_3_GRAY
  },
  {
    EL_EM_GATE_3_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EM_GATE_3_GRAY_ACTIVE
  },
  {
    EL_EM_GATE_3_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EM_GATE_3_GRAY_ACTIVE
  },
  {
    EL_EM_GATE_4_GRAY,			-1, -1, FALSE,
    IMG_EM_GATE_4_GRAY
  },
  {
    EL_EM_GATE_4_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EM_GATE_4_GRAY_ACTIVE
  },
  {
    EL_EM_GATE_4_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EM_GATE_4_GRAY_ACTIVE
  },
  {
    EL_EXIT_CLOSED,			-1, -1, FALSE,
    IMG_EXIT_CLOSED
  },
  {
    EL_EXIT_OPENING,			-1, -1, FALSE,
    IMG_EXIT_OPENING
  },
  {
    EL_EXIT_OPEN,			-1, -1, FALSE,
    IMG_EXIT_OPEN
  },
  {
    EL_EXIT_CLOSING,			-1, -1, FALSE,
    IMG_EXIT_CLOSING
  },
  {
    EL_BALLOON,				-1, -1, FALSE,
    IMG_BALLOON
  },
  {
    EL_BALLOON,				ACTION_MOVING, -1, FALSE,
    IMG_BALLOON_MOVING
  },
  {
    EL_BALLOON,				ACTION_PUSHING, -1, FALSE,
    IMG_BALLOON_PUSHING
  },
  {
    EL_BALLOON_SWITCH_LEFT,		-1, -1, FALSE,
    IMG_BALLOON_SWITCH_LEFT
  },
  {
    EL_BALLOON_SWITCH_RIGHT,		-1, -1, FALSE,
    IMG_BALLOON_SWITCH_RIGHT
  },
  {
    EL_BALLOON_SWITCH_UP,		-1, -1, FALSE,
    IMG_BALLOON_SWITCH_UP
  },
  {
    EL_BALLOON_SWITCH_DOWN,		-1, -1, FALSE,
    IMG_BALLOON_SWITCH_DOWN
  },
  {
    EL_BALLOON_SWITCH_ANY,		-1, -1, FALSE,
    IMG_BALLOON_SWITCH_ANY
  },
  {
    EL_BALLOON_SWITCH_NONE,		-1, -1, FALSE,
    IMG_BALLOON_SWITCH_NONE
  },
  {
    EL_SPRING,				-1, -1, FALSE,
    IMG_SPRING
  },
  {
    EL_EMC_STEELWALL_1,			-1, -1, FALSE,
    IMG_EMC_STEELWALL_1
  },
  {
    EL_EMC_STEELWALL_2,			-1, -1, FALSE,
    IMG_EMC_STEELWALL_2
  },
  {
    EL_EMC_STEELWALL_3,			-1, -1, FALSE,
    IMG_EMC_STEELWALL_3
  },
  {
    EL_EMC_STEELWALL_4,			-1, -1, FALSE,
    IMG_EMC_STEELWALL_4
  },
  {
    EL_EMC_WALL_1,			-1, -1, FALSE,
    IMG_EMC_WALL_1
  },
  {
    EL_EMC_WALL_2,			-1, -1, FALSE,
    IMG_EMC_WALL_2
  },
  {
    EL_EMC_WALL_3,			-1, -1, FALSE,
    IMG_EMC_WALL_3
  },
  {
    EL_EMC_WALL_4,			-1, -1, FALSE,
    IMG_EMC_WALL_4
  },
  {
    EL_EMC_WALL_5,			-1, -1, FALSE,
    IMG_EMC_WALL_5
  },
  {
    EL_EMC_WALL_6,			-1, -1, FALSE,
    IMG_EMC_WALL_6
  },
  {
    EL_EMC_WALL_7,			-1, -1, FALSE,
    IMG_EMC_WALL_7
  },
  {
    EL_EMC_WALL_8,			-1, -1, FALSE,
    IMG_EMC_WALL_8
  },
  {
    EL_INVISIBLE_STEELWALL,		-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL
  },
  {
    EL_INVISIBLE_STEELWALL_ACTIVE,	-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_ACTIVE
  },
  {
    EL_INVISIBLE_STEELWALL,		ACTION_ACTIVE, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_ACTIVE
  },
  {
    EL_INVISIBLE_WALL,			-1, -1, FALSE,
    IMG_INVISIBLE_WALL
  },
  {
    EL_INVISIBLE_WALL_ACTIVE,		-1, -1, FALSE,
    IMG_INVISIBLE_WALL_ACTIVE
  },
  {
    EL_INVISIBLE_WALL,			ACTION_ACTIVE, -1, FALSE,
    IMG_INVISIBLE_WALL_ACTIVE
  },
  {
    EL_INVISIBLE_SAND,			-1, -1, FALSE,
    IMG_INVISIBLE_SAND
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		-1, -1, FALSE,
    IMG_INVISIBLE_SAND_ACTIVE
  },
  {
    EL_INVISIBLE_SAND,			ACTION_ACTIVE, -1, FALSE,
    IMG_INVISIBLE_SAND_ACTIVE
  },
  {
    EL_INVISIBLE_SAND,			ACTION_ACTIVE, -1, TRUE,
    IMG_INVISIBLE_SAND_ACTIVE_CRUMBLED
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		-1, -1, TRUE,
    IMG_INVISIBLE_SAND_ACTIVE_CRUMBLED
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_LEFT, TRUE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_LEFT_CRUMBLED
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_RIGHT, TRUE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_RIGHT_CRUMBLED
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_UP, TRUE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_UP_CRUMBLED
  },
  {
    EL_INVISIBLE_SAND_ACTIVE,		ACTION_DIGGING, MV_BIT_DOWN, TRUE,
    IMG_INVISIBLE_SAND_ACTIVE_DIGGING_DOWN_CRUMBLED
  },
  {
    EL_CONVEYOR_BELT_1_MIDDLE,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_1_MIDDLE_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_1_MIDDLE,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_1_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_1_LEFT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_LEFT
  },
  {
    EL_CONVEYOR_BELT_1_LEFT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_1_LEFT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_1_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_1_RIGHT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_RIGHT
  },
  {
    EL_CONVEYOR_BELT_1_RIGHT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_1_RIGHT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_1_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_1_SWITCH_LEFT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_SWITCH_LEFT
  },
  {
    EL_CONVEYOR_BELT_1_SWITCH_MIDDLE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_SWITCH_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_1_SWITCH_RIGHT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_1_SWITCH_RIGHT
  },
  {
    EL_CONVEYOR_BELT_2_MIDDLE,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_2_MIDDLE_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_2_MIDDLE,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_2_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_2_LEFT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_LEFT
  },
  {
    EL_CONVEYOR_BELT_2_LEFT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_2_LEFT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_2_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_2_RIGHT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_RIGHT
  },
  {
    EL_CONVEYOR_BELT_2_RIGHT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_2_RIGHT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_2_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_2_SWITCH_LEFT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_SWITCH_LEFT
  },
  {
    EL_CONVEYOR_BELT_2_SWITCH_MIDDLE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_SWITCH_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_2_SWITCH_RIGHT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_2_SWITCH_RIGHT
  },
  {
    EL_CONVEYOR_BELT_3_MIDDLE,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_3_MIDDLE_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_3_MIDDLE,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_3_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_3_LEFT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_LEFT
  },
  {
    EL_CONVEYOR_BELT_3_LEFT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_3_LEFT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_3_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_3_RIGHT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_RIGHT
  },
  {
    EL_CONVEYOR_BELT_3_RIGHT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_3_RIGHT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_3_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_3_SWITCH_LEFT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_SWITCH_LEFT
  },
  {
    EL_CONVEYOR_BELT_3_SWITCH_MIDDLE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_SWITCH_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_3_SWITCH_RIGHT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_3_SWITCH_RIGHT
  },
  {
    EL_CONVEYOR_BELT_4_MIDDLE,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_4_MIDDLE_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_4_MIDDLE,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_4_MIDDLE_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_4_LEFT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_LEFT
  },
  {
    EL_CONVEYOR_BELT_4_LEFT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_4_LEFT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_4_LEFT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_4_RIGHT,		-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_RIGHT
  },
  {
    EL_CONVEYOR_BELT_4_RIGHT_ACTIVE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_4_RIGHT,		ACTION_ACTIVE, -1, FALSE,
    IMG_CONVEYOR_BELT_4_RIGHT_ACTIVE
  },
  {
    EL_CONVEYOR_BELT_4_SWITCH_LEFT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_SWITCH_LEFT
  },
  {
    EL_CONVEYOR_BELT_4_SWITCH_MIDDLE,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_SWITCH_MIDDLE
  },
  {
    EL_CONVEYOR_BELT_4_SWITCH_RIGHT,	-1, -1, FALSE,
    IMG_CONVEYOR_BELT_4_SWITCH_RIGHT
  },
  {
    EL_SWITCHGATE_SWITCH_UP,		-1, -1, FALSE,
    IMG_SWITCHGATE_SWITCH_UP
  },
  {
    EL_SWITCHGATE_SWITCH_DOWN,		-1, -1, FALSE,
    IMG_SWITCHGATE_SWITCH_DOWN
  },
  {
    EL_LIGHT_SWITCH,			-1, -1, FALSE,
    IMG_LIGHT_SWITCH
  },
  {
    EL_LIGHT_SWITCH_ACTIVE,		-1, -1, FALSE,
    IMG_LIGHT_SWITCH_ACTIVE
  },
  {
    EL_LIGHT_SWITCH,			ACTION_ACTIVE, -1, FALSE,
    IMG_LIGHT_SWITCH_ACTIVE
  },
  {
    EL_TIMEGATE_SWITCH,			-1, -1, FALSE,
    IMG_TIMEGATE_SWITCH
  },
  {
    EL_TIMEGATE_SWITCH_ACTIVE,		-1, -1, FALSE,
    IMG_TIMEGATE_SWITCH_ACTIVE
  },
  {
    EL_TIMEGATE_SWITCH,			ACTION_ACTIVE, -1, FALSE,
    IMG_TIMEGATE_SWITCH_ACTIVE
  },
  {
    EL_ENVELOPE_1,			-1, -1, FALSE,
    IMG_ENVELOPE_1
  },
  {
    EL_ENVELOPE_1,			ACTION_COLLECTING, -1, FALSE,
    IMG_ENVELOPE_1_COLLECTING
  },
  {
    EL_ENVELOPE_2,			-1, -1, FALSE,
    IMG_ENVELOPE_2
  },
  {
    EL_ENVELOPE_2,			ACTION_COLLECTING, -1, FALSE,
    IMG_ENVELOPE_2_COLLECTING
  },
  {
    EL_ENVELOPE_3,			-1, -1, FALSE,
    IMG_ENVELOPE_3
  },
  {
    EL_ENVELOPE_3,			ACTION_COLLECTING, -1, FALSE,
    IMG_ENVELOPE_3_COLLECTING
  },
  {
    EL_ENVELOPE_4,			-1, -1, FALSE,
    IMG_ENVELOPE_4
  },
  {
    EL_ENVELOPE_4,			ACTION_COLLECTING, -1, FALSE,
    IMG_ENVELOPE_4_COLLECTING
  },
  {
    EL_SIGN_EXCLAMATION,		-1, -1, FALSE,
    IMG_SIGN_EXCLAMATION
  },
  {
    EL_SIGN_STOP,			-1, -1, FALSE,
    IMG_SIGN_STOP
  },
  {
    EL_LANDMINE,			-1, -1, FALSE,
    IMG_LANDMINE
  },
  {
    EL_STEELWALL_SLIPPERY,		-1, -1, FALSE,
    IMG_STEELWALL_SLIPPERY
  },
  {
    EL_EXTRA_TIME,			-1, -1, FALSE,
    IMG_EXTRA_TIME
  },
  {
    EL_SHIELD_NORMAL,			-1, -1, FALSE,
    IMG_SHIELD_NORMAL
  },
  {
    EL_SHIELD_NORMAL_ACTIVE,		-1, -1, FALSE,
    IMG_SHIELD_NORMAL_ACTIVE
  },
  {
    EL_SHIELD_NORMAL,			ACTION_ACTIVE, -1, FALSE,
    IMG_SHIELD_NORMAL_ACTIVE
  },
  {
    EL_SHIELD_DEADLY,			-1, -1, FALSE,
    IMG_SHIELD_DEADLY
  },
  {
    EL_SHIELD_DEADLY_ACTIVE,		-1, -1, FALSE,
    IMG_SHIELD_DEADLY_ACTIVE
  },
  {
    EL_SHIELD_DEADLY,			ACTION_ACTIVE, -1, FALSE,
    IMG_SHIELD_DEADLY_ACTIVE
  },
  {
    EL_SWITCHGATE_CLOSED,		-1, -1, FALSE,
    IMG_SWITCHGATE_CLOSED
  },
  {
    EL_SWITCHGATE_OPENING,		-1, -1, FALSE,
    IMG_SWITCHGATE_OPENING
  },
  {
    EL_SWITCHGATE_OPEN,			-1, -1, FALSE,
    IMG_SWITCHGATE_OPEN
  },
  {
    EL_SWITCHGATE_CLOSING,		-1, -1, FALSE,
    IMG_SWITCHGATE_CLOSING
  },
  {
    EL_TIMEGATE_CLOSED,			-1, -1, FALSE,
    IMG_TIMEGATE_CLOSED
  },
  {
    EL_TIMEGATE_OPENING,		-1, -1, FALSE,
    IMG_TIMEGATE_OPENING
  },
  {
    EL_TIMEGATE_OPEN,			-1, -1, FALSE,
    IMG_TIMEGATE_OPEN
  },
  {
    EL_TIMEGATE_CLOSING,		-1, -1, FALSE,
    IMG_TIMEGATE_CLOSING
  },
  {
    EL_PEARL,				-1, -1, FALSE,
    IMG_PEARL
  },
  {
    EL_PEARL_BREAKING,			-1, -1, FALSE,
    IMG_PEARL_BREAKING
  },
  {
    EL_PEARL,				ACTION_BREAKING, -1, FALSE,
    IMG_PEARL_BREAKING
  },
  {
    EL_CRYSTAL,				-1, -1, FALSE,
    IMG_CRYSTAL
  },
  {
    EL_WALL_PEARL,			-1, -1, FALSE,
    IMG_WALL_PEARL
  },
  {
    EL_WALL_CRYSTAL,			-1, -1, FALSE,
    IMG_WALL_CRYSTAL
  },
  {
    EL_TUBE_RIGHT_DOWN,			-1, -1, FALSE,
    IMG_TUBE_RIGHT_DOWN
  },
  {
    EL_TUBE_HORIZONTAL_DOWN,		-1, -1, FALSE,
    IMG_TUBE_HORIZONTAL_DOWN
  },
  {
    EL_TUBE_LEFT_DOWN,			-1, -1, FALSE,
    IMG_TUBE_LEFT_DOWN
  },
  {
    EL_TUBE_HORIZONTAL,			-1, -1, FALSE,
    IMG_TUBE_HORIZONTAL
  },
  {
    EL_TUBE_VERTICAL_RIGHT,		-1, -1, FALSE,
    IMG_TUBE_VERTICAL_RIGHT
  },
  {
    EL_TUBE_ANY,			-1, -1, FALSE,
    IMG_TUBE_ANY
  },
  {
    EL_TUBE_VERTICAL_LEFT,		-1, -1, FALSE,
    IMG_TUBE_VERTICAL_LEFT
  },
  {
    EL_TUBE_VERTICAL,			-1, -1, FALSE,
    IMG_TUBE_VERTICAL
  },
  {
    EL_TUBE_RIGHT_UP,			-1, -1, FALSE,
    IMG_TUBE_RIGHT_UP
  },
  {
    EL_TUBE_HORIZONTAL_UP,		-1, -1, FALSE,
    IMG_TUBE_HORIZONTAL_UP
  },
  {
    EL_TUBE_LEFT_UP,			-1, -1, FALSE,
    IMG_TUBE_LEFT_UP
  },
  {
    EL_TRAP,				-1, -1, FALSE,
    IMG_TRAP
  },
  {
    EL_TRAP_ACTIVE,			-1, -1, FALSE,
    IMG_TRAP_ACTIVE
  },
  {
    EL_TRAP,				ACTION_ACTIVE, -1, FALSE,
    IMG_TRAP_ACTIVE
  },
  {
    EL_DX_SUPABOMB,			-1, -1, FALSE,
    IMG_DX_SUPABOMB
  },
  {
    EL_KEY_1,				-1, -1, FALSE,
    IMG_KEY_1
  },
  {
    EL_KEY_2,				-1, -1, FALSE,
    IMG_KEY_2
  },
  {
    EL_KEY_3,				-1, -1, FALSE,
    IMG_KEY_3
  },
  {
    EL_KEY_4,				-1, -1, FALSE,
    IMG_KEY_4
  },
  {
    EL_GATE_1,				-1, -1, FALSE,
    IMG_GATE_1
  },
  {
    EL_GATE_2,				-1, -1, FALSE,
    IMG_GATE_2
  },
  {
    EL_GATE_3,				-1, -1, FALSE,
    IMG_GATE_3
  },
  {
    EL_GATE_4,				-1, -1, FALSE,
    IMG_GATE_4
  },
  {
    EL_GATE_1_GRAY,			-1, -1, FALSE,
    IMG_GATE_1_GRAY
  },
  {
    EL_GATE_1_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_GATE_1_GRAY_ACTIVE
  },
  {
    EL_GATE_1_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_GATE_1_GRAY_ACTIVE
  },
  {
    EL_GATE_2_GRAY,			-1, -1, FALSE,
    IMG_GATE_2_GRAY
  },
  {
    EL_GATE_2_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_GATE_2_GRAY_ACTIVE
  },
  {
    EL_GATE_2_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_GATE_2_GRAY_ACTIVE
  },
  {
    EL_GATE_3_GRAY,			-1, -1, FALSE,
    IMG_GATE_3_GRAY
  },
  {
    EL_GATE_3_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_GATE_3_GRAY_ACTIVE
  },
  {
    EL_GATE_3_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_GATE_3_GRAY_ACTIVE
  },
  {
    EL_GATE_4_GRAY,			-1, -1, FALSE,
    IMG_GATE_4_GRAY
  },
  {
    EL_GATE_4_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_GATE_4_GRAY_ACTIVE
  },
  {
    EL_GATE_4_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_GATE_4_GRAY_ACTIVE
  },
  {
    EL_GAME_OF_LIFE,			-1, -1, FALSE,
    IMG_GAME_OF_LIFE
  },
  {
    EL_BIOMAZE,				-1, -1, FALSE,
    IMG_BIOMAZE
  },
  {
    EL_PACMAN,				-1, -1, FALSE,
    IMG_PACMAN
  },
  {
    EL_PACMAN_RIGHT,			-1, -1, FALSE,
    IMG_PACMAN_RIGHT
  },
  {
    EL_PACMAN,				-1, MV_BIT_RIGHT, FALSE,
    IMG_PACMAN_RIGHT
  },
  {
    EL_PACMAN_UP,			-1, -1, FALSE,
    IMG_PACMAN_UP
  },
  {
    EL_PACMAN,				-1, MV_BIT_UP, FALSE,
    IMG_PACMAN_UP
  },
  {
    EL_PACMAN_LEFT,			-1, -1, FALSE,
    IMG_PACMAN_LEFT
  },
  {
    EL_PACMAN,				-1, MV_BIT_LEFT, FALSE,
    IMG_PACMAN_LEFT
  },
  {
    EL_PACMAN_DOWN,			-1, -1, FALSE,
    IMG_PACMAN_DOWN
  },
  {
    EL_PACMAN,				-1, MV_BIT_DOWN, FALSE,
    IMG_PACMAN_DOWN
  },
  {
    EL_PACMAN,				ACTION_TURNING_FROM_RIGHT, -1, FALSE,
    IMG_PACMAN_TURNING_FROM_RIGHT
  },
  {
    EL_PACMAN,				ACTION_TURNING_FROM_UP, -1, FALSE,
    IMG_PACMAN_TURNING_FROM_UP
  },
  {
    EL_PACMAN,				ACTION_TURNING_FROM_LEFT, -1, FALSE,
    IMG_PACMAN_TURNING_FROM_LEFT
  },
  {
    EL_PACMAN,				ACTION_TURNING_FROM_DOWN, -1, FALSE,
    IMG_PACMAN_TURNING_FROM_DOWN
  },
  {
    EL_LAMP,				-1, -1, FALSE,
    IMG_LAMP
  },
  {
    EL_LAMP_ACTIVE,			-1, -1, FALSE,
    IMG_LAMP_ACTIVE
  },
  {
    EL_LAMP,				ACTION_ACTIVE, -1, FALSE,
    IMG_LAMP_ACTIVE
  },
  {
    EL_TIME_ORB_FULL,			-1, -1, FALSE,
    IMG_TIME_ORB_FULL
  },
  {
    EL_TIME_ORB_EMPTY,			-1, -1, FALSE,
    IMG_TIME_ORB_EMPTY
  },
  {
    EL_EMERALD_YELLOW,			-1, -1, FALSE,
    IMG_EMERALD_YELLOW
  },
  {
    EL_EMERALD_YELLOW,			ACTION_MOVING, -1, FALSE,
    IMG_EMERALD_YELLOW_MOVING
  },
  {
    EL_EMERALD_YELLOW,			ACTION_FALLING, -1, FALSE,
    IMG_EMERALD_YELLOW_FALLING
  },
  {
    EL_EMERALD_RED,			-1, -1, FALSE,
    IMG_EMERALD_RED
  },
  {
    EL_EMERALD_RED,			ACTION_MOVING, -1, FALSE,
    IMG_EMERALD_RED_MOVING
  },
  {
    EL_EMERALD_RED,			ACTION_FALLING, -1, FALSE,
    IMG_EMERALD_RED_FALLING
  },
  {
    EL_EMERALD_PURPLE,			-1, -1, FALSE,
    IMG_EMERALD_PURPLE
  },
  {
    EL_EMERALD_PURPLE,			ACTION_MOVING, -1, FALSE,
    IMG_EMERALD_PURPLE_MOVING
  },
  {
    EL_EMERALD_PURPLE,			ACTION_FALLING, -1, FALSE,
    IMG_EMERALD_PURPLE_FALLING
  },
  {
    EL_WALL_EMERALD_YELLOW,		-1, -1, FALSE,
    IMG_WALL_EMERALD_YELLOW
  },
  {
    EL_WALL_EMERALD_RED,		-1, -1, FALSE,
    IMG_WALL_EMERALD_RED
  },
  {
    EL_WALL_EMERALD_PURPLE,		-1, -1, FALSE,
    IMG_WALL_EMERALD_PURPLE
  },
  {
    EL_WALL_BD_DIAMOND,			-1, -1, FALSE,
    IMG_WALL_BD_DIAMOND
  },
  {
    EL_EXPANDABLE_WALL,			-1, -1, FALSE,
    IMG_EXPANDABLE_WALL
  },
  {
    EL_EXPANDABLE_WALL_HORIZONTAL,	-1, -1, FALSE,
    IMG_EXPANDABLE_WALL_HORIZONTAL
  },
  {
    EL_EXPANDABLE_WALL_VERTICAL,	-1, -1, FALSE,
    IMG_EXPANDABLE_WALL_VERTICAL
  },
  {
    EL_EXPANDABLE_WALL_ANY,		-1, -1, FALSE,
    IMG_EXPANDABLE_WALL_ANY
  },
  {
    EL_BD_EXPANDABLE_WALL,		-1, -1, FALSE,
    IMG_BD_EXPANDABLE_WALL
  },
  {
    EL_EXPANDABLE_WALL,			ACTION_GROWING, MV_BIT_LEFT, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_LEFT
  },
  {
    EL_EXPANDABLE_WALL_GROWING,		-1, MV_BIT_LEFT, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_LEFT
  },
  {
    EL_EXPANDABLE_WALL,			ACTION_GROWING, MV_BIT_RIGHT, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_RIGHT
  },
  {
    EL_EXPANDABLE_WALL_GROWING,		-1, MV_BIT_RIGHT, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_RIGHT
  },
  {
    EL_EXPANDABLE_WALL,			ACTION_GROWING, MV_BIT_UP, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_UP
  },
  {
    EL_EXPANDABLE_WALL_GROWING,		-1, MV_BIT_UP, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_UP
  },
  {
    EL_EXPANDABLE_WALL,			ACTION_GROWING, MV_BIT_DOWN, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_DOWN
  },
  {
    EL_EXPANDABLE_WALL_GROWING,		-1, MV_BIT_DOWN, FALSE,
    IMG_EXPANDABLE_WALL_GROWING_DOWN
  },
  {
    EL_BLACK_ORB,			-1, -1, FALSE,
    IMG_BLACK_ORB
  },
  {
    EL_SPEED_PILL,			-1, -1, FALSE,
    IMG_SPEED_PILL
  },
  {
    EL_DARK_YAMYAM,			-1, -1, FALSE,
    IMG_DARK_YAMYAM
  },
  {
    EL_DYNABOMB,			-1, -1, FALSE,
    IMG_DYNABOMB
  },
  {
    EL_DYNABOMB_ACTIVE,			-1, -1, FALSE,
    IMG_DYNABOMB_ACTIVE
  },
  {
    EL_DYNABOMB,			ACTION_ACTIVE, -1, FALSE,
    IMG_DYNABOMB_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_1,		-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_1
  },
  {
    EL_DYNABOMB_PLAYER_1_ACTIVE,	-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_1_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_1,		ACTION_ACTIVE, -1, FALSE,
    IMG_DYNABOMB_PLAYER_1_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_2,		-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_2
  },
  {
    EL_DYNABOMB_PLAYER_2_ACTIVE,	-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_2_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_2,		ACTION_ACTIVE, -1, FALSE,
    IMG_DYNABOMB_PLAYER_2_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_3,		-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_3
  },
  {
    EL_DYNABOMB_PLAYER_3_ACTIVE,	-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_3_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_3,		ACTION_ACTIVE, -1, FALSE,
    IMG_DYNABOMB_PLAYER_3_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_4,		-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_4
  },
  {
    EL_DYNABOMB_PLAYER_4_ACTIVE,	-1, -1, FALSE,
    IMG_DYNABOMB_PLAYER_4_ACTIVE
  },
  {
    EL_DYNABOMB_PLAYER_4,		ACTION_ACTIVE, -1, FALSE,
    IMG_DYNABOMB_PLAYER_4_ACTIVE
  },
  {
    EL_DYNABOMB_INCREASE_NUMBER,	-1, -1, FALSE,
    IMG_DYNABOMB_INCREASE_NUMBER
  },
  {
    EL_DYNABOMB_INCREASE_SIZE,		-1, -1, FALSE,
    IMG_DYNABOMB_INCREASE_SIZE
  },
  {
    EL_DYNABOMB_INCREASE_POWER,		-1, -1, FALSE,
    IMG_DYNABOMB_INCREASE_POWER
  },
  {
    EL_PIG,				-1, -1, FALSE,
    IMG_PIG
  },
  {
    EL_PIG,				-1, MV_BIT_DOWN, FALSE,
    IMG_PIG_DOWN
  },
  {
    EL_PIG,				-1, MV_BIT_UP, FALSE,
    IMG_PIG_UP
  },
  {
    EL_PIG,				-1, MV_BIT_LEFT, FALSE,
    IMG_PIG_LEFT
  },
  {
    EL_PIG,				-1, MV_BIT_RIGHT, FALSE,
    IMG_PIG_RIGHT
  },
  {
    EL_PIG,				ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_PIG_MOVING_DOWN
  },
  {
    EL_PIG,				ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_PIG_MOVING_UP
  },
  {
    EL_PIG,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_PIG_MOVING_LEFT
  },
  {
    EL_PIG,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_PIG_MOVING_RIGHT
  },
  {
    EL_PIG,				ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_PIG_DIGGING_DOWN
  },
  {
    EL_PIG,				ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_PIG_DIGGING_UP
  },
  {
    EL_PIG,				ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_PIG_DIGGING_LEFT
  },
  {
    EL_PIG,				ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_PIG_DIGGING_RIGHT
  },
  {
    EL_DRAGON,				-1, -1, FALSE,
    IMG_DRAGON
  },
  {
    EL_DRAGON,				-1, MV_BIT_DOWN, FALSE,
    IMG_DRAGON_DOWN
  },
  {
    EL_DRAGON,				-1, MV_BIT_UP, FALSE,
    IMG_DRAGON_UP
  },
  {
    EL_DRAGON,				-1, MV_BIT_LEFT, FALSE,
    IMG_DRAGON_LEFT
  },
  {
    EL_DRAGON,				-1, MV_BIT_RIGHT, FALSE,
    IMG_DRAGON_RIGHT
  },
  {
    EL_DRAGON,				ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_DRAGON_MOVING_DOWN
  },
  {
    EL_DRAGON,				ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_DRAGON_MOVING_UP
  },
  {
    EL_DRAGON,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_DRAGON_MOVING_LEFT
  },
  {
    EL_DRAGON,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_DRAGON_MOVING_RIGHT
  },
  {
    EL_DRAGON,				ACTION_ATTACKING, MV_BIT_DOWN, FALSE,
    IMG_DRAGON_ATTACKING_DOWN
  },
  {
    EL_DRAGON,				ACTION_ATTACKING, MV_BIT_UP, FALSE,
    IMG_DRAGON_ATTACKING_UP
  },
  {
    EL_DRAGON,				ACTION_ATTACKING, MV_BIT_LEFT, FALSE,
    IMG_DRAGON_ATTACKING_LEFT
  },
  {
    EL_DRAGON,				ACTION_ATTACKING, MV_BIT_RIGHT, FALSE,
    IMG_DRAGON_ATTACKING_RIGHT
  },
  {
    EL_MOLE,				-1, -1, FALSE,
    IMG_MOLE
  },
  {
    EL_MOLE_DOWN,			-1, -1, FALSE,
    IMG_MOLE_DOWN
  },
  {
    EL_MOLE,				-1, MV_BIT_DOWN, FALSE,
    IMG_MOLE_DOWN
  },
  {
    EL_MOLE_UP,				-1, -1, FALSE,
    IMG_MOLE_UP
  },
  {
    EL_MOLE,				-1, MV_BIT_UP, FALSE,
    IMG_MOLE_UP
  },
  {
    EL_MOLE_LEFT,			-1, -1, FALSE,
    IMG_MOLE_LEFT
  },
  {
    EL_MOLE,				-1, MV_BIT_LEFT, FALSE,
    IMG_MOLE_LEFT
  },
  {
    EL_MOLE_RIGHT,			-1, -1, FALSE,
    IMG_MOLE_RIGHT
  },
  {
    EL_MOLE,				-1, MV_BIT_RIGHT, FALSE,
    IMG_MOLE_RIGHT
  },
  {
    EL_MOLE,				ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_MOLE_MOVING_DOWN
  },
  {
    EL_MOLE,				ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_MOLE_MOVING_UP
  },
  {
    EL_MOLE,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_MOLE_MOVING_LEFT
  },
  {
    EL_MOLE,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_MOLE_MOVING_RIGHT
  },
  {
    EL_MOLE,				ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_MOLE_DIGGING_DOWN
  },
  {
    EL_MOLE,				ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_MOLE_DIGGING_UP
  },
  {
    EL_MOLE,				ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_MOLE_DIGGING_LEFT
  },
  {
    EL_MOLE,				ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_MOLE_DIGGING_RIGHT
  },
  {
    EL_PENGUIN,				-1, -1, FALSE,
    IMG_PENGUIN
  },
  {
    EL_PENGUIN,				-1, MV_BIT_DOWN, FALSE,
    IMG_PENGUIN_DOWN
  },
  {
    EL_PENGUIN,				-1, MV_BIT_UP, FALSE,
    IMG_PENGUIN_UP
  },
  {
    EL_PENGUIN,				-1, MV_BIT_LEFT, FALSE,
    IMG_PENGUIN_LEFT
  },
  {
    EL_PENGUIN,				-1, MV_BIT_RIGHT, FALSE,
    IMG_PENGUIN_RIGHT
  },
  {
    EL_PENGUIN,				ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_PENGUIN_MOVING_DOWN
  },
  {
    EL_PENGUIN,				ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_PENGUIN_MOVING_UP
  },
  {
    EL_PENGUIN,				ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_PENGUIN_MOVING_LEFT
  },
  {
    EL_PENGUIN,				ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_PENGUIN_MOVING_RIGHT
  },
  {
    EL_SATELLITE,			-1, -1, FALSE,
    IMG_SATELLITE
  },
  {
    EL_STONEBLOCK,			-1, -1, FALSE,
    IMG_STONEBLOCK
  },
  {
    EL_PLAYER_1,			-1, -1, FALSE,
    IMG_PLAYER_1
  },
  {
    EL_PLAYER_1,			-1, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_1_DOWN
  },
  {
    EL_PLAYER_1,			-1, MV_BIT_UP, FALSE,
    IMG_PLAYER_1_UP
  },
  {
    EL_PLAYER_1,			-1, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_1_LEFT
  },
  {
    EL_PLAYER_1,			-1, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_1_RIGHT
  },
  {
    EL_PLAYER_1,			ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_1_MOVING_DOWN
  },
  {
    EL_PLAYER_1,			ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_PLAYER_1_MOVING_UP
  },
  {
    EL_PLAYER_1,			ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_1_MOVING_LEFT
  },
  {
    EL_PLAYER_1,			ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_1_MOVING_RIGHT
  },
  {
    EL_PLAYER_1,			ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_1_DIGGING_DOWN
  },
  {
    EL_PLAYER_1,			ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_PLAYER_1_DIGGING_UP
  },
  {
    EL_PLAYER_1,			ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_1_DIGGING_LEFT
  },
  {
    EL_PLAYER_1,			ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_1_DIGGING_RIGHT
  },
  {
    EL_PLAYER_1,			ACTION_COLLECTING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_1_COLLECTING_DOWN
  },
  {
    EL_PLAYER_1,			ACTION_COLLECTING, MV_BIT_UP, FALSE,
    IMG_PLAYER_1_COLLECTING_UP
  },
  {
    EL_PLAYER_1,			ACTION_COLLECTING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_1_COLLECTING_LEFT
  },
  {
    EL_PLAYER_1,			ACTION_COLLECTING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_1_COLLECTING_RIGHT
  },
  {
    EL_PLAYER_1,			ACTION_PUSHING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_1_PUSHING_DOWN
  },
  {
    EL_PLAYER_1,			ACTION_PUSHING, MV_BIT_UP, FALSE,
    IMG_PLAYER_1_PUSHING_UP
  },
  {
    EL_PLAYER_1,			ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_1_PUSHING_LEFT
  },
  {
    EL_PLAYER_1,			ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_1_PUSHING_RIGHT
  },
  {
    EL_PLAYER_1,			ACTION_SNAPPING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_1_SNAPPING_DOWN
  },
  {
    EL_PLAYER_1,			ACTION_SNAPPING, MV_BIT_UP, FALSE,
    IMG_PLAYER_1_SNAPPING_UP
  },
  {
    EL_PLAYER_1,			ACTION_SNAPPING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_1_SNAPPING_LEFT
  },
  {
    EL_PLAYER_1,			ACTION_SNAPPING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_1_SNAPPING_RIGHT
  },
  {
    EL_PLAYER_2,			-1, -1, FALSE,
    IMG_PLAYER_2
  },
  {
    EL_PLAYER_2,			-1, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_2_DOWN
  },
  {
    EL_PLAYER_2,			-1, MV_BIT_UP, FALSE,
    IMG_PLAYER_2_UP
  },
  {
    EL_PLAYER_2,			-1, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_2_LEFT
  },
  {
    EL_PLAYER_2,			-1, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_2_RIGHT
  },
  {
    EL_PLAYER_2,			ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_2_MOVING_DOWN
  },
  {
    EL_PLAYER_2,			ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_PLAYER_2_MOVING_UP
  },
  {
    EL_PLAYER_2,			ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_2_MOVING_LEFT
  },
  {
    EL_PLAYER_2,			ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_2_MOVING_RIGHT
  },
  {
    EL_PLAYER_2,			ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_2_DIGGING_DOWN
  },
  {
    EL_PLAYER_2,			ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_PLAYER_2_DIGGING_UP
  },
  {
    EL_PLAYER_2,			ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_2_DIGGING_LEFT
  },
  {
    EL_PLAYER_2,			ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_2_DIGGING_RIGHT
  },
  {
    EL_PLAYER_2,			ACTION_COLLECTING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_2_COLLECTING_DOWN
  },
  {
    EL_PLAYER_2,			ACTION_COLLECTING, MV_BIT_UP, FALSE,
    IMG_PLAYER_2_COLLECTING_UP
  },
  {
    EL_PLAYER_2,			ACTION_COLLECTING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_2_COLLECTING_LEFT
  },
  {
    EL_PLAYER_2,			ACTION_COLLECTING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_2_COLLECTING_RIGHT
  },
  {
    EL_PLAYER_2,			ACTION_PUSHING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_2_PUSHING_DOWN
  },
  {
    EL_PLAYER_2,			ACTION_PUSHING, MV_BIT_UP, FALSE,
    IMG_PLAYER_2_PUSHING_UP
  },
  {
    EL_PLAYER_2,			ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_2_PUSHING_LEFT
  },
  {
    EL_PLAYER_2,			ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_2_PUSHING_RIGHT
  },
  {
    EL_PLAYER_2,			ACTION_SNAPPING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_2_SNAPPING_DOWN
  },
  {
    EL_PLAYER_2,			ACTION_SNAPPING, MV_BIT_UP, FALSE,
    IMG_PLAYER_2_SNAPPING_UP
  },
  {
    EL_PLAYER_2,			ACTION_SNAPPING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_2_SNAPPING_LEFT
  },
  {
    EL_PLAYER_2,			ACTION_SNAPPING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_2_SNAPPING_RIGHT
  },
  {
    EL_PLAYER_3,			-1, -1, FALSE,
    IMG_PLAYER_3
  },
  {
    EL_PLAYER_3,			-1, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_3_DOWN
  },
  {
    EL_PLAYER_3,			-1, MV_BIT_UP, FALSE,
    IMG_PLAYER_3_UP
  },
  {
    EL_PLAYER_3,			-1, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_3_LEFT
  },
  {
    EL_PLAYER_3,			-1, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_3_RIGHT
  },
  {
    EL_PLAYER_3,			ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_3_MOVING_DOWN
  },
  {
    EL_PLAYER_3,			ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_PLAYER_3_MOVING_UP
  },
  {
    EL_PLAYER_3,			ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_3_MOVING_LEFT
  },
  {
    EL_PLAYER_3,			ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_3_MOVING_RIGHT
  },
  {
    EL_PLAYER_3,			ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_3_DIGGING_DOWN
  },
  {
    EL_PLAYER_3,			ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_PLAYER_3_DIGGING_UP
  },
  {
    EL_PLAYER_3,			ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_3_DIGGING_LEFT
  },
  {
    EL_PLAYER_3,			ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_3_DIGGING_RIGHT
  },
  {
    EL_PLAYER_3,			ACTION_COLLECTING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_3_COLLECTING_DOWN
  },
  {
    EL_PLAYER_3,			ACTION_COLLECTING, MV_BIT_UP, FALSE,
    IMG_PLAYER_3_COLLECTING_UP
  },
  {
    EL_PLAYER_3,			ACTION_COLLECTING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_3_COLLECTING_LEFT
  },
  {
    EL_PLAYER_3,			ACTION_COLLECTING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_3_COLLECTING_RIGHT
  },
  {
    EL_PLAYER_3,			ACTION_PUSHING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_3_PUSHING_DOWN
  },
  {
    EL_PLAYER_3,			ACTION_PUSHING, MV_BIT_UP, FALSE,
    IMG_PLAYER_3_PUSHING_UP
  },
  {
    EL_PLAYER_3,			ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_3_PUSHING_LEFT
  },
  {
    EL_PLAYER_3,			ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_3_PUSHING_RIGHT
  },
  {
    EL_PLAYER_3,			ACTION_SNAPPING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_3_SNAPPING_DOWN
  },
  {
    EL_PLAYER_3,			ACTION_SNAPPING, MV_BIT_UP, FALSE,
    IMG_PLAYER_3_SNAPPING_UP
  },
  {
    EL_PLAYER_3,			ACTION_SNAPPING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_3_SNAPPING_LEFT
  },
  {
    EL_PLAYER_3,			ACTION_SNAPPING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_3_SNAPPING_RIGHT
  },
  {
    EL_PLAYER_4,			-1, -1, FALSE,
    IMG_PLAYER_4
  },
  {
    EL_PLAYER_4,			-1, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_4_DOWN
  },
  {
    EL_PLAYER_4,			-1, MV_BIT_UP, FALSE,
    IMG_PLAYER_4_UP
  },
  {
    EL_PLAYER_4,			-1, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_4_LEFT
  },
  {
    EL_PLAYER_4,			-1, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_4_RIGHT
  },
  {
    EL_PLAYER_4,			ACTION_MOVING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_4_MOVING_DOWN
  },
  {
    EL_PLAYER_4,			ACTION_MOVING, MV_BIT_UP, FALSE,
    IMG_PLAYER_4_MOVING_UP
  },
  {
    EL_PLAYER_4,			ACTION_MOVING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_4_MOVING_LEFT
  },
  {
    EL_PLAYER_4,			ACTION_MOVING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_4_MOVING_RIGHT
  },
  {
    EL_PLAYER_4,			ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_4_DIGGING_DOWN
  },
  {
    EL_PLAYER_4,			ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_PLAYER_4_DIGGING_UP
  },
  {
    EL_PLAYER_4,			ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_4_DIGGING_LEFT
  },
  {
    EL_PLAYER_4,			ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_4_DIGGING_RIGHT
  },
  {
    EL_PLAYER_4,			ACTION_COLLECTING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_4_COLLECTING_DOWN
  },
  {
    EL_PLAYER_4,			ACTION_COLLECTING, MV_BIT_UP, FALSE,
    IMG_PLAYER_4_COLLECTING_UP
  },
  {
    EL_PLAYER_4,			ACTION_COLLECTING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_4_COLLECTING_LEFT
  },
  {
    EL_PLAYER_4,			ACTION_COLLECTING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_4_COLLECTING_RIGHT
  },
  {
    EL_PLAYER_4,			ACTION_PUSHING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_4_PUSHING_DOWN
  },
  {
    EL_PLAYER_4,			ACTION_PUSHING, MV_BIT_UP, FALSE,
    IMG_PLAYER_4_PUSHING_UP
  },
  {
    EL_PLAYER_4,			ACTION_PUSHING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_4_PUSHING_LEFT
  },
  {
    EL_PLAYER_4,			ACTION_PUSHING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_4_PUSHING_RIGHT
  },
  {
    EL_PLAYER_4,			ACTION_SNAPPING, MV_BIT_DOWN, FALSE,
    IMG_PLAYER_4_SNAPPING_DOWN
  },
  {
    EL_PLAYER_4,			ACTION_SNAPPING, MV_BIT_UP, FALSE,
    IMG_PLAYER_4_SNAPPING_UP
  },
  {
    EL_PLAYER_4,			ACTION_SNAPPING, MV_BIT_LEFT, FALSE,
    IMG_PLAYER_4_SNAPPING_LEFT
  },
  {
    EL_PLAYER_4,			ACTION_SNAPPING, MV_BIT_RIGHT, FALSE,
    IMG_PLAYER_4_SNAPPING_RIGHT
  },
  {
    EL_DEFAULT,				ACTION_EXPLODING, -1, FALSE,
    IMG_DEFAULT_EXPLODING
  },
  {
    EL_STEELWALL_TOPLEFT,		-1, -1, FALSE,
    IMG_STEELWALL_TOPLEFT
  },
  {
    EL_STEELWALL_TOPRIGHT,		-1, -1, FALSE,
    IMG_STEELWALL_TOPRIGHT
  },
  {
    EL_STEELWALL_BOTTOMLEFT,		-1, -1, FALSE,
    IMG_STEELWALL_BOTTOMLEFT
  },
  {
    EL_STEELWALL_BOTTOMRIGHT,		-1, -1, FALSE,
    IMG_STEELWALL_BOTTOMRIGHT
  },
  {
    EL_STEELWALL_HORIZONTAL,		-1, -1, FALSE,
    IMG_STEELWALL_HORIZONTAL
  },
  {
    EL_STEELWALL_VERTICAL,		-1, -1, FALSE,
    IMG_STEELWALL_VERTICAL
  },
  {
    EL_INVISIBLE_STEELWALL_TOPLEFT,	-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_TOPLEFT
  },
  {
    EL_INVISIBLE_STEELWALL_TOPRIGHT,	-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_TOPRIGHT
  },
  {
    EL_INVISIBLE_STEELWALL_BOTTOMLEFT,	-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_BOTTOMLEFT
  },
  {
    EL_INVISIBLE_STEELWALL_BOTTOMRIGHT,	-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_BOTTOMRIGHT
  },
  {
    EL_INVISIBLE_STEELWALL_HORIZONTAL,	-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_HORIZONTAL
  },
  {
    EL_INVISIBLE_STEELWALL_VERTICAL,	-1, -1, FALSE,
    IMG_INVISIBLE_STEELWALL_VERTICAL
  },
  {
    EL_ARROW_LEFT,			-1, -1, FALSE,
    IMG_ARROW_LEFT
  },
  {
    EL_ARROW_RIGHT,			-1, -1, FALSE,
    IMG_ARROW_RIGHT
  },
  {
    EL_ARROW_UP,			-1, -1, FALSE,
    IMG_ARROW_UP
  },
  {
    EL_ARROW_DOWN,			-1, -1, FALSE,
    IMG_ARROW_DOWN
  },
  {
    EL_UNKNOWN,				-1, -1, FALSE,
    IMG_UNKNOWN
  },
  {
    EL_TRIGGER_ELEMENT,			-1, -1, FALSE,
    IMG_TRIGGER_ELEMENT
  },
  {
    EL_TRIGGER_PLAYER,			-1, -1, FALSE,
    IMG_TRIGGER_PLAYER
  },
  {
    EL_TRIGGER_CE_VALUE,		-1, -1, FALSE,
    IMG_TRIGGER_CE_VALUE
  },
  {
    EL_TRIGGER_CE_SCORE,		-1, -1, FALSE,
    IMG_TRIGGER_CE_SCORE
  },
  {
    EL_CURRENT_CE_VALUE,		-1, -1, FALSE,
    IMG_CURRENT_CE_VALUE
  },
  {
    EL_CURRENT_CE_SCORE,		-1, -1, FALSE,
    IMG_CURRENT_CE_SCORE
  },
  {
    EL_PREV_CE_1,			-1, -1, FALSE,
    IMG_PREV_CE_1
  },
  {
    EL_PREV_CE_2,			-1, -1, FALSE,
    IMG_PREV_CE_2
  },
  {
    EL_PREV_CE_3,			-1, -1, FALSE,
    IMG_PREV_CE_3
  },
  {
    EL_PREV_CE_4,			-1, -1, FALSE,
    IMG_PREV_CE_4
  },
  {
    EL_PREV_CE_5,			-1, -1, FALSE,
    IMG_PREV_CE_5
  },
  {
    EL_PREV_CE_6,			-1, -1, FALSE,
    IMG_PREV_CE_6
  },
  {
    EL_PREV_CE_7,			-1, -1, FALSE,
    IMG_PREV_CE_7
  },
  {
    EL_PREV_CE_8,			-1, -1, FALSE,
    IMG_PREV_CE_8
  },
  {
    EL_NEXT_CE_1,			-1, -1, FALSE,
    IMG_NEXT_CE_1
  },
  {
    EL_NEXT_CE_2,			-1, -1, FALSE,
    IMG_NEXT_CE_2
  },
  {
    EL_NEXT_CE_3,			-1, -1, FALSE,
    IMG_NEXT_CE_3
  },
  {
    EL_NEXT_CE_4,			-1, -1, FALSE,
    IMG_NEXT_CE_4
  },
  {
    EL_NEXT_CE_5,			-1, -1, FALSE,
    IMG_NEXT_CE_5
  },
  {
    EL_NEXT_CE_6,			-1, -1, FALSE,
    IMG_NEXT_CE_6
  },
  {
    EL_NEXT_CE_7,			-1, -1, FALSE,
    IMG_NEXT_CE_7
  },
  {
    EL_NEXT_CE_8,			-1, -1, FALSE,
    IMG_NEXT_CE_8
  },
  {
    EL_SELF,				-1, -1, FALSE,
    IMG_SELF
  },
  {
    EL_ANY_ELEMENT,			-1, -1, FALSE,
    IMG_ANY_ELEMENT
  },
  {
    EL_EMC_KEY_5,			-1, -1, FALSE,
    IMG_EMC_KEY_5
  },
  {
    EL_EMC_KEY_6,			-1, -1, FALSE,
    IMG_EMC_KEY_6
  },
  {
    EL_EMC_KEY_7,			-1, -1, FALSE,
    IMG_EMC_KEY_7
  },
  {
    EL_EMC_KEY_8,			-1, -1, FALSE,
    IMG_EMC_KEY_8
  },
  {
    EL_EMC_GATE_5,			-1, -1, FALSE,
    IMG_EMC_GATE_5
  },
  {
    EL_EMC_GATE_6,			-1, -1, FALSE,
    IMG_EMC_GATE_6
  },
  {
    EL_EMC_GATE_7,			-1, -1, FALSE,
    IMG_EMC_GATE_7
  },
  {
    EL_EMC_GATE_8,			-1, -1, FALSE,
    IMG_EMC_GATE_8
  },
  {
    EL_EMC_GATE_5_GRAY,			-1, -1, FALSE,
    IMG_EMC_GATE_5_GRAY
  },
  {
    EL_EMC_GATE_5_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EMC_GATE_5_GRAY_ACTIVE
  },
  {
    EL_EMC_GATE_5_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_GATE_5_GRAY_ACTIVE
  },
  {
    EL_EMC_GATE_6_GRAY,			-1, -1, FALSE,
    IMG_EMC_GATE_6_GRAY
  },
  {
    EL_EMC_GATE_6_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EMC_GATE_6_GRAY_ACTIVE
  },
  {
    EL_EMC_GATE_6_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_GATE_6_GRAY_ACTIVE
  },
  {
    EL_EMC_GATE_7_GRAY,			-1, -1, FALSE,
    IMG_EMC_GATE_7_GRAY
  },
  {
    EL_EMC_GATE_7_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EMC_GATE_7_GRAY_ACTIVE
  },
  {
    EL_EMC_GATE_7_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_GATE_7_GRAY_ACTIVE
  },
  {
    EL_EMC_GATE_8_GRAY,			-1, -1, FALSE,
    IMG_EMC_GATE_8_GRAY
  },
  {
    EL_EMC_GATE_8_GRAY_ACTIVE,		-1, -1, FALSE,
    IMG_EMC_GATE_8_GRAY_ACTIVE
  },
  {
    EL_EMC_GATE_8_GRAY,			ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_GATE_8_GRAY_ACTIVE
  },
  {
    EL_EMC_ANDROID,			-1, -1, FALSE,
    IMG_EMC_ANDROID
  },
  {
    EL_EMC_ANDROID,			ACTION_SHRINKING, MV_BIT_UPLEFT, FALSE,
    IMG_EMC_ANDROID_SHRINKING_UPLEFT
  },
  {
    EL_EMC_ANDROID,			ACTION_GROWING, MV_BIT_DOWNRIGHT, FALSE,
    IMG_EMC_ANDROID_GROWING_DOWNRIGHT
  },
  {
    EL_EMC_ANDROID,			ACTION_SHRINKING, MV_BIT_DOWNLEFT, FALSE,
    IMG_EMC_ANDROID_SHRINKING_DOWNLEFT
  },
  {
    EL_EMC_ANDROID,			ACTION_GROWING, MV_BIT_UPRIGHT, FALSE,
    IMG_EMC_ANDROID_GROWING_UPRIGHT
  },
  {
    EL_EMC_ANDROID,			ACTION_SHRINKING, MV_BIT_UPRIGHT, FALSE,
    IMG_EMC_ANDROID_SHRINKING_UPRIGHT
  },
  {
    EL_EMC_ANDROID,			ACTION_GROWING, MV_BIT_DOWNLEFT, FALSE,
    IMG_EMC_ANDROID_GROWING_DOWNLEFT
  },
  {
    EL_EMC_ANDROID,			ACTION_SHRINKING, MV_BIT_DOWNRIGHT, FALSE,
    IMG_EMC_ANDROID_SHRINKING_DOWNRIGHT
  },
  {
    EL_EMC_ANDROID,			ACTION_GROWING, MV_BIT_UPLEFT, FALSE,
    IMG_EMC_ANDROID_GROWING_UPLEFT
  },
  {
    EL_EMC_GRASS,			-1, -1, FALSE,
    IMG_EMC_GRASS
  },
  {
    EL_EMC_GRASS,			-1, -1, TRUE,
    IMG_EMC_GRASS_CRUMBLED
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_LEFT, FALSE,
    IMG_EMC_GRASS_DIGGING_LEFT
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_RIGHT, FALSE,
    IMG_EMC_GRASS_DIGGING_RIGHT
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_UP, FALSE,
    IMG_EMC_GRASS_DIGGING_UP
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_DOWN, FALSE,
    IMG_EMC_GRASS_DIGGING_DOWN
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_LEFT, TRUE,
    IMG_EMC_GRASS_DIGGING_LEFT_CRUMBLED
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_RIGHT, TRUE,
    IMG_EMC_GRASS_DIGGING_RIGHT_CRUMBLED
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_UP, TRUE,
    IMG_EMC_GRASS_DIGGING_UP_CRUMBLED
  },
  {
    EL_EMC_GRASS,			ACTION_DIGGING, MV_BIT_DOWN, TRUE,
    IMG_EMC_GRASS_DIGGING_DOWN_CRUMBLED
  },
  {
    EL_EMC_MAGIC_BALL,			-1, -1, FALSE,
    IMG_EMC_MAGIC_BALL
  },
  {
    EL_EMC_MAGIC_BALL_ACTIVE,		-1, -1, FALSE,
    IMG_EMC_MAGIC_BALL_ACTIVE
  },
  {
    EL_EMC_MAGIC_BALL,			ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_MAGIC_BALL_ACTIVE
  },
  {
    EL_EMC_MAGIC_BALL,			ACTION_DROPPING, -1, FALSE,
    IMG_EMC_MAGIC_BALL_DROPPING
  },
  {
    EL_EMC_MAGIC_BALL_SWITCH,		-1, -1, FALSE,
    IMG_EMC_MAGIC_BALL_SWITCH
  },
  {
    EL_EMC_MAGIC_BALL_SWITCH_ACTIVE,	-1, -1, FALSE,
    IMG_EMC_MAGIC_BALL_SWITCH_ACTIVE
  },
  {
    EL_EMC_MAGIC_BALL_SWITCH,		ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_MAGIC_BALL_SWITCH_ACTIVE
  },
  {
    EL_EMC_SPRING_BUMPER,		-1, -1, FALSE,
    IMG_EMC_SPRING_BUMPER
  },
  {
    EL_EMC_SPRING_BUMPER_ACTIVE,	-1, -1, FALSE,
    IMG_EMC_SPRING_BUMPER_ACTIVE
  },
  {
    EL_EMC_SPRING_BUMPER,		ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_SPRING_BUMPER_ACTIVE
  },
  {
    EL_EMC_PLANT,			-1, -1, FALSE,
    IMG_EMC_PLANT
  },
  {
    EL_EMC_PLANT,			-1, -1, TRUE,
    IMG_EMC_PLANT_CRUMBLED
  },
  {
    EL_EMC_LENSES,			-1, -1, FALSE,
    IMG_EMC_LENSES
  },
  {
    EL_EMC_MAGNIFIER,			-1, -1, FALSE,
    IMG_EMC_MAGNIFIER
  },
  {
    EL_EMC_WALL_9,			-1, -1, FALSE,
    IMG_EMC_WALL_9
  },
  {
    EL_EMC_WALL_10,			-1, -1, FALSE,
    IMG_EMC_WALL_10
  },
  {
    EL_EMC_WALL_11,			-1, -1, FALSE,
    IMG_EMC_WALL_11
  },
  {
    EL_EMC_WALL_12,			-1, -1, FALSE,
    IMG_EMC_WALL_12
  },
  {
    EL_EMC_WALL_13,			-1, -1, FALSE,
    IMG_EMC_WALL_13
  },
  {
    EL_EMC_WALL_14,			-1, -1, FALSE,
    IMG_EMC_WALL_14
  },
  {
    EL_EMC_WALL_15,			-1, -1, FALSE,
    IMG_EMC_WALL_15
  },
  {
    EL_EMC_WALL_16,			-1, -1, FALSE,
    IMG_EMC_WALL_16
  },
  {
    EL_EMC_WALL_SLIPPERY_1,		-1, -1, FALSE,
    IMG_EMC_WALL_SLIPPERY_1
  },
  {
    EL_EMC_WALL_SLIPPERY_2,		-1, -1, FALSE,
    IMG_EMC_WALL_SLIPPERY_2
  },
  {
    EL_EMC_WALL_SLIPPERY_3,		-1, -1, FALSE,
    IMG_EMC_WALL_SLIPPERY_3
  },
  {
    EL_EMC_WALL_SLIPPERY_4,		-1, -1, FALSE,
    IMG_EMC_WALL_SLIPPERY_4
  },
  {
    EL_EMC_FAKE_GRASS,			-1, -1, FALSE,
    IMG_EMC_FAKE_GRASS
  },
  {
    EL_EMC_FAKE_GRASS,			-1, -1, TRUE,
    IMG_EMC_FAKE_GRASS_CRUMBLED
  },
  {
    EL_EMC_FAKE_GRASS_ACTIVE,		-1, -1, FALSE,
    IMG_EMC_FAKE_GRASS_ACTIVE
  },
  {
    EL_EMC_FAKE_GRASS,			ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_FAKE_GRASS_ACTIVE
  },
  {
    EL_EMC_FAKE_GRASS,			ACTION_ACTIVE, -1, TRUE,
    IMG_EMC_FAKE_GRASS_ACTIVE_CRUMBLED
  },
  {
    EL_EMC_FAKE_GRASS_ACTIVE,		-1, -1, TRUE,
    IMG_EMC_FAKE_GRASS_ACTIVE_CRUMBLED
  },
  {
    EL_EMC_FAKE_ACID,			-1, -1, FALSE,
    IMG_EMC_FAKE_ACID
  },
  {
    EL_EMC_DRIPPER,			-1, -1, FALSE,
    IMG_EMC_DRIPPER
  },
  {
    EL_EMC_DRIPPER_ACTIVE,		-1, -1, FALSE,
    IMG_EMC_DRIPPER_ACTIVE
  },
  {
    EL_EMC_DRIPPER,			ACTION_ACTIVE, -1, FALSE,
    IMG_EMC_DRIPPER_ACTIVE
  },
  {
    EL_BD_BUTTERFLY_DOWN,		-1, -1, FALSE,
    IMG_BD_BUTTERFLY
  },
  {
    EL_BD_BUTTERFLY_LEFT,		-1, -1, FALSE,
    IMG_BD_BUTTERFLY
  },
  {
    EL_BD_BUTTERFLY_RIGHT,		-1, -1, FALSE,
    IMG_BD_BUTTERFLY
  },
  {
    EL_BD_BUTTERFLY_UP,			-1, -1, FALSE,
    IMG_BD_BUTTERFLY
  },
  {
    EL_BD_FIREFLY_DOWN,			-1, -1, FALSE,
    IMG_BD_FIREFLY
  },
  {
    EL_BD_FIREFLY_LEFT,			-1, -1, FALSE,
    IMG_BD_FIREFLY
  },
  {
    EL_BD_FIREFLY_RIGHT,		-1, -1, FALSE,
    IMG_BD_FIREFLY
  },
  {
    EL_BD_FIREFLY_UP,			-1, -1, FALSE,
    IMG_BD_FIREFLY
  },
  {
    EL_DOOR_WHITE,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_DOOR_WHITE_GRAY,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_DX_UNKNOWN_15,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_DX_UNKNOWN_42,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_KEY_WHITE,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_EXIT,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_HEART,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_ONEWAY,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_OTHER,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_PARKING,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_RADIOACTIVITY,		-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_ROUND,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_TRIANGLE,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_WHEELCHAIR,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_SIGN_YINYANG,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_CHAR_SPACE,			-1, -1, FALSE,
    IMG_CHAR_SPACE
  },
  {
    EL_CHAR_EXCLAM,			-1, -1, FALSE,
    IMG_CHAR_EXCLAM
  },
  {
    EL_CHAR_QUOTEDBL,			-1, -1, FALSE,
    IMG_CHAR_QUOTEDBL
  },
  {
    EL_CHAR_NUMBERSIGN,			-1, -1, FALSE,
    IMG_CHAR_NUMBERSIGN
  },
  {
    EL_CHAR_DOLLAR,			-1, -1, FALSE,
    IMG_CHAR_DOLLAR
  },
  {
    EL_CHAR_PERCENT,			-1, -1, FALSE,
    IMG_CHAR_PERCENT
  },
  {
    EL_CHAR_AMPERSAND,			-1, -1, FALSE,
    IMG_CHAR_AMPERSAND
  },
  {
    EL_CHAR_APOSTROPHE,			-1, -1, FALSE,
    IMG_CHAR_APOSTROPHE
  },
  {
    EL_CHAR_PARENLEFT,			-1, -1, FALSE,
    IMG_CHAR_PARENLEFT
  },
  {
    EL_CHAR_PARENRIGHT,			-1, -1, FALSE,
    IMG_CHAR_PARENRIGHT
  },
  {
    EL_CHAR_ASTERISK,			-1, -1, FALSE,
    IMG_CHAR_ASTERISK
  },
  {
    EL_CHAR_PLUS,			-1, -1, FALSE,
    IMG_CHAR_PLUS
  },
  {
    EL_CHAR_COMMA,			-1, -1, FALSE,
    IMG_CHAR_COMMA
  },
  {
    EL_CHAR_MINUS,			-1, -1, FALSE,
    IMG_CHAR_MINUS
  },
  {
    EL_CHAR_PERIOD,			-1, -1, FALSE,
    IMG_CHAR_PERIOD
  },
  {
    EL_CHAR_SLASH,			-1, -1, FALSE,
    IMG_CHAR_SLASH
  },
  {
    EL_CHAR_0,				-1, -1, FALSE,
    IMG_CHAR_0
  },
  {
    EL_CHAR_1,				-1, -1, FALSE,
    IMG_CHAR_1
  },
  {
    EL_CHAR_2,				-1, -1, FALSE,
    IMG_CHAR_2
  },
  {
    EL_CHAR_3,				-1, -1, FALSE,
    IMG_CHAR_3
  },
  {
    EL_CHAR_4,				-1, -1, FALSE,
    IMG_CHAR_4
  },
  {
    EL_CHAR_5,				-1, -1, FALSE,
    IMG_CHAR_5
  },
  {
    EL_CHAR_6,				-1, -1, FALSE,
    IMG_CHAR_6
  },
  {
    EL_CHAR_7,				-1, -1, FALSE,
    IMG_CHAR_7
  },
  {
    EL_CHAR_8,				-1, -1, FALSE,
    IMG_CHAR_8
  },
  {
    EL_CHAR_9,				-1, -1, FALSE,
    IMG_CHAR_9
  },
  {
    EL_CHAR_COLON,			-1, -1, FALSE,
    IMG_CHAR_COLON
  },
  {
    EL_CHAR_SEMICOLON,			-1, -1, FALSE,
    IMG_CHAR_SEMICOLON
  },
  {
    EL_CHAR_LESS,			-1, -1, FALSE,
    IMG_CHAR_LESS
  },
  {
    EL_CHAR_EQUAL,			-1, -1, FALSE,
    IMG_CHAR_EQUAL
  },
  {
    EL_CHAR_GREATER,			-1, -1, FALSE,
    IMG_CHAR_GREATER
  },
  {
    EL_CHAR_QUESTION,			-1, -1, FALSE,
    IMG_CHAR_QUESTION
  },
  {
    EL_CHAR_AT,				-1, -1, FALSE,
    IMG_CHAR_AT
  },
  {
    EL_CHAR_A,				-1, -1, FALSE,
    IMG_CHAR_A
  },
  {
    EL_CHAR_B,				-1, -1, FALSE,
    IMG_CHAR_B
  },
  {
    EL_CHAR_C,				-1, -1, FALSE,
    IMG_CHAR_C
  },
  {
    EL_CHAR_D,				-1, -1, FALSE,
    IMG_CHAR_D
  },
  {
    EL_CHAR_E,				-1, -1, FALSE,
    IMG_CHAR_E
  },
  {
    EL_CHAR_F,				-1, -1, FALSE,
    IMG_CHAR_F
  },
  {
    EL_CHAR_G,				-1, -1, FALSE,
    IMG_CHAR_G
  },
  {
    EL_CHAR_H,				-1, -1, FALSE,
    IMG_CHAR_H
  },
  {
    EL_CHAR_I,				-1, -1, FALSE,
    IMG_CHAR_I
  },
  {
    EL_CHAR_J,				-1, -1, FALSE,
    IMG_CHAR_J
  },
  {
    EL_CHAR_K,				-1, -1, FALSE,
    IMG_CHAR_K
  },
  {
    EL_CHAR_L,				-1, -1, FALSE,
    IMG_CHAR_L
  },
  {
    EL_CHAR_M,				-1, -1, FALSE,
    IMG_CHAR_M
  },
  {
    EL_CHAR_N,				-1, -1, FALSE,
    IMG_CHAR_N
  },
  {
    EL_CHAR_O,				-1, -1, FALSE,
    IMG_CHAR_O
  },
  {
    EL_CHAR_P,				-1, -1, FALSE,
    IMG_CHAR_P
  },
  {
    EL_CHAR_Q,				-1, -1, FALSE,
    IMG_CHAR_Q
  },
  {
    EL_CHAR_R,				-1, -1, FALSE,
    IMG_CHAR_R
  },
  {
    EL_CHAR_S,				-1, -1, FALSE,
    IMG_CHAR_S
  },
  {
    EL_CHAR_T,				-1, -1, FALSE,
    IMG_CHAR_T
  },
  {
    EL_CHAR_U,				-1, -1, FALSE,
    IMG_CHAR_U
  },
  {
    EL_CHAR_V,				-1, -1, FALSE,
    IMG_CHAR_V
  },
  {
    EL_CHAR_W,				-1, -1, FALSE,
    IMG_CHAR_W
  },
  {
    EL_CHAR_X,				-1, -1, FALSE,
    IMG_CHAR_X
  },
  {
    EL_CHAR_Y,				-1, -1, FALSE,
    IMG_CHAR_Y
  },
  {
    EL_CHAR_Z,				-1, -1, FALSE,
    IMG_CHAR_Z
  },
  {
    EL_CHAR_BRACKETLEFT,		-1, -1, FALSE,
    IMG_CHAR_BRACKETLEFT
  },
  {
    EL_CHAR_BACKSLASH,			-1, -1, FALSE,
    IMG_CHAR_BACKSLASH
  },
  {
    EL_CHAR_BRACKETRIGHT,		-1, -1, FALSE,
    IMG_CHAR_BRACKETRIGHT
  },
  {
    EL_CHAR_ASCIICIRCUM,		-1, -1, FALSE,
    IMG_CHAR_ASCIICIRCUM
  },
  {
    EL_CHAR_UNDERSCORE,			-1, -1, FALSE,
    IMG_CHAR_UNDERSCORE
  },
  {
    EL_CHAR_COPYRIGHT,			-1, -1, FALSE,
    IMG_CHAR_COPYRIGHT
  },
  {
    EL_CHAR_AUMLAUT,			-1, -1, FALSE,
    IMG_CHAR_AUMLAUT
  },
  {
    EL_CHAR_OUMLAUT,			-1, -1, FALSE,
    IMG_CHAR_OUMLAUT
  },
  {
    EL_CHAR_UUMLAUT,			-1, -1, FALSE,
    IMG_CHAR_UUMLAUT
  },
  {
    EL_CHAR_DEGREE,			-1, -1, FALSE,
    IMG_CHAR_DEGREE
  },
  {
    EL_CHAR_TRADEMARK,			-1, -1, FALSE,
    IMG_CHAR_TRADEMARK
  },
  {
    EL_CHAR_CURSOR,			-1, -1, FALSE,
    IMG_CHAR_CURSOR
  },
  {
    EL_CUSTOM_1,			-1, -1, FALSE,
    IMG_CUSTOM_1
  },
  {
    EL_CUSTOM_2,			-1, -1, FALSE,
    IMG_CUSTOM_2
  },
  {
    EL_CUSTOM_3,			-1, -1, FALSE,
    IMG_CUSTOM_3
  },
  {
    EL_CUSTOM_4,			-1, -1, FALSE,
    IMG_CUSTOM_4
  },
  {
    EL_CUSTOM_5,			-1, -1, FALSE,
    IMG_CUSTOM_5
  },
  {
    EL_CUSTOM_6,			-1, -1, FALSE,
    IMG_CUSTOM_6
  },
  {
    EL_CUSTOM_7,			-1, -1, FALSE,
    IMG_CUSTOM_7
  },
  {
    EL_CUSTOM_8,			-1, -1, FALSE,
    IMG_CUSTOM_8
  },
  {
    EL_CUSTOM_9,			-1, -1, FALSE,
    IMG_CUSTOM_9
  },
  {
    EL_CUSTOM_10,			-1, -1, FALSE,
    IMG_CUSTOM_10
  },
  {
    EL_CUSTOM_11,			-1, -1, FALSE,
    IMG_CUSTOM_11
  },
  {
    EL_CUSTOM_12,			-1, -1, FALSE,
    IMG_CUSTOM_12
  },
  {
    EL_CUSTOM_13,			-1, -1, FALSE,
    IMG_CUSTOM_13
  },
  {
    EL_CUSTOM_14,			-1, -1, FALSE,
    IMG_CUSTOM_14
  },
  {
    EL_CUSTOM_15,			-1, -1, FALSE,
    IMG_CUSTOM_15
  },
  {
    EL_CUSTOM_16,			-1, -1, FALSE,
    IMG_CUSTOM_16
  },
  {
    EL_CUSTOM_17,			-1, -1, FALSE,
    IMG_CUSTOM_17
  },
  {
    EL_CUSTOM_18,			-1, -1, FALSE,
    IMG_CUSTOM_18
  },
  {
    EL_CUSTOM_19,			-1, -1, FALSE,
    IMG_CUSTOM_19
  },
  {
    EL_CUSTOM_20,			-1, -1, FALSE,
    IMG_CUSTOM_20
  },
  {
    EL_CUSTOM_21,			-1, -1, FALSE,
    IMG_CUSTOM_21
  },
  {
    EL_CUSTOM_22,			-1, -1, FALSE,
    IMG_CUSTOM_22
  },
  {
    EL_CUSTOM_23,			-1, -1, FALSE,
    IMG_CUSTOM_23
  },
  {
    EL_CUSTOM_24,			-1, -1, FALSE,
    IMG_CUSTOM_24
  },
  {
    EL_CUSTOM_25,			-1, -1, FALSE,
    IMG_CUSTOM_25
  },
  {
    EL_CUSTOM_26,			-1, -1, FALSE,
    IMG_CUSTOM_26
  },
  {
    EL_CUSTOM_27,			-1, -1, FALSE,
    IMG_CUSTOM_27
  },
  {
    EL_CUSTOM_28,			-1, -1, FALSE,
    IMG_CUSTOM_28
  },
  {
    EL_CUSTOM_29,			-1, -1, FALSE,
    IMG_CUSTOM_29
  },
  {
    EL_CUSTOM_30,			-1, -1, FALSE,
    IMG_CUSTOM_30
  },
  {
    EL_CUSTOM_31,			-1, -1, FALSE,
    IMG_CUSTOM_31
  },
  {
    EL_CUSTOM_32,			-1, -1, FALSE,
    IMG_CUSTOM_32
  },
  {
    EL_CUSTOM_33,			-1, -1, FALSE,
    IMG_CUSTOM_33
  },
  {
    EL_CUSTOM_34,			-1, -1, FALSE,
    IMG_CUSTOM_34
  },
  {
    EL_CUSTOM_35,			-1, -1, FALSE,
    IMG_CUSTOM_35
  },
  {
    EL_CUSTOM_36,			-1, -1, FALSE,
    IMG_CUSTOM_36
  },
  {
    EL_CUSTOM_37,			-1, -1, FALSE,
    IMG_CUSTOM_37
  },
  {
    EL_CUSTOM_38,			-1, -1, FALSE,
    IMG_CUSTOM_38
  },
  {
    EL_CUSTOM_39,			-1, -1, FALSE,
    IMG_CUSTOM_39
  },
  {
    EL_CUSTOM_40,			-1, -1, FALSE,
    IMG_CUSTOM_40
  },
  {
    EL_CUSTOM_41,			-1, -1, FALSE,
    IMG_CUSTOM_41
  },
  {
    EL_CUSTOM_42,			-1, -1, FALSE,
    IMG_CUSTOM_42
  },
  {
    EL_CUSTOM_43,			-1, -1, FALSE,
    IMG_CUSTOM_43
  },
  {
    EL_CUSTOM_44,			-1, -1, FALSE,
    IMG_CUSTOM_44
  },
  {
    EL_CUSTOM_45,			-1, -1, FALSE,
    IMG_CUSTOM_45
  },
  {
    EL_CUSTOM_46,			-1, -1, FALSE,
    IMG_CUSTOM_46
  },
  {
    EL_CUSTOM_47,			-1, -1, FALSE,
    IMG_CUSTOM_47
  },
  {
    EL_CUSTOM_48,			-1, -1, FALSE,
    IMG_CUSTOM_48
  },
  {
    EL_CUSTOM_49,			-1, -1, FALSE,
    IMG_CUSTOM_49
  },
  {
    EL_CUSTOM_50,			-1, -1, FALSE,
    IMG_CUSTOM_50
  },
  {
    EL_CUSTOM_51,			-1, -1, FALSE,
    IMG_CUSTOM_51
  },
  {
    EL_CUSTOM_52,			-1, -1, FALSE,
    IMG_CUSTOM_52
  },
  {
    EL_CUSTOM_53,			-1, -1, FALSE,
    IMG_CUSTOM_53
  },
  {
    EL_CUSTOM_54,			-1, -1, FALSE,
    IMG_CUSTOM_54
  },
  {
    EL_CUSTOM_55,			-1, -1, FALSE,
    IMG_CUSTOM_55
  },
  {
    EL_CUSTOM_56,			-1, -1, FALSE,
    IMG_CUSTOM_56
  },
  {
    EL_CUSTOM_57,			-1, -1, FALSE,
    IMG_CUSTOM_57
  },
  {
    EL_CUSTOM_58,			-1, -1, FALSE,
    IMG_CUSTOM_58
  },
  {
    EL_CUSTOM_59,			-1, -1, FALSE,
    IMG_CUSTOM_59
  },
  {
    EL_CUSTOM_60,			-1, -1, FALSE,
    IMG_CUSTOM_60
  },
  {
    EL_CUSTOM_61,			-1, -1, FALSE,
    IMG_CUSTOM_61
  },
  {
    EL_CUSTOM_62,			-1, -1, FALSE,
    IMG_CUSTOM_62
  },
  {
    EL_CUSTOM_63,			-1, -1, FALSE,
    IMG_CUSTOM_63
  },
  {
    EL_CUSTOM_64,			-1, -1, FALSE,
    IMG_CUSTOM_64
  },
  {
    EL_CUSTOM_65,			-1, -1, FALSE,
    IMG_CUSTOM_65
  },
  {
    EL_CUSTOM_66,			-1, -1, FALSE,
    IMG_CUSTOM_66
  },
  {
    EL_CUSTOM_67,			-1, -1, FALSE,
    IMG_CUSTOM_67
  },
  {
    EL_CUSTOM_68,			-1, -1, FALSE,
    IMG_CUSTOM_68
  },
  {
    EL_CUSTOM_69,			-1, -1, FALSE,
    IMG_CUSTOM_69
  },
  {
    EL_CUSTOM_70,			-1, -1, FALSE,
    IMG_CUSTOM_70
  },
  {
    EL_CUSTOM_71,			-1, -1, FALSE,
    IMG_CUSTOM_71
  },
  {
    EL_CUSTOM_72,			-1, -1, FALSE,
    IMG_CUSTOM_72
  },
  {
    EL_CUSTOM_73,			-1, -1, FALSE,
    IMG_CUSTOM_73
  },
  {
    EL_CUSTOM_74,			-1, -1, FALSE,
    IMG_CUSTOM_74
  },
  {
    EL_CUSTOM_75,			-1, -1, FALSE,
    IMG_CUSTOM_75
  },
  {
    EL_CUSTOM_76,			-1, -1, FALSE,
    IMG_CUSTOM_76
  },
  {
    EL_CUSTOM_77,			-1, -1, FALSE,
    IMG_CUSTOM_77
  },
  {
    EL_CUSTOM_78,			-1, -1, FALSE,
    IMG_CUSTOM_78
  },
  {
    EL_CUSTOM_79,			-1, -1, FALSE,
    IMG_CUSTOM_79
  },
  {
    EL_CUSTOM_80,			-1, -1, FALSE,
    IMG_CUSTOM_80
  },
  {
    EL_CUSTOM_81,			-1, -1, FALSE,
    IMG_CUSTOM_81
  },
  {
    EL_CUSTOM_82,			-1, -1, FALSE,
    IMG_CUSTOM_82
  },
  {
    EL_CUSTOM_83,			-1, -1, FALSE,
    IMG_CUSTOM_83
  },
  {
    EL_CUSTOM_84,			-1, -1, FALSE,
    IMG_CUSTOM_84
  },
  {
    EL_CUSTOM_85,			-1, -1, FALSE,
    IMG_CUSTOM_85
  },
  {
    EL_CUSTOM_86,			-1, -1, FALSE,
    IMG_CUSTOM_86
  },
  {
    EL_CUSTOM_87,			-1, -1, FALSE,
    IMG_CUSTOM_87
  },
  {
    EL_CUSTOM_88,			-1, -1, FALSE,
    IMG_CUSTOM_88
  },
  {
    EL_CUSTOM_89,			-1, -1, FALSE,
    IMG_CUSTOM_89
  },
  {
    EL_CUSTOM_90,			-1, -1, FALSE,
    IMG_CUSTOM_90
  },
  {
    EL_CUSTOM_91,			-1, -1, FALSE,
    IMG_CUSTOM_91
  },
  {
    EL_CUSTOM_92,			-1, -1, FALSE,
    IMG_CUSTOM_92
  },
  {
    EL_CUSTOM_93,			-1, -1, FALSE,
    IMG_CUSTOM_93
  },
  {
    EL_CUSTOM_94,			-1, -1, FALSE,
    IMG_CUSTOM_94
  },
  {
    EL_CUSTOM_95,			-1, -1, FALSE,
    IMG_CUSTOM_95
  },
  {
    EL_CUSTOM_96,			-1, -1, FALSE,
    IMG_CUSTOM_96
  },
  {
    EL_CUSTOM_97,			-1, -1, FALSE,
    IMG_CUSTOM_97
  },
  {
    EL_CUSTOM_98,			-1, -1, FALSE,
    IMG_CUSTOM_98
  },
  {
    EL_CUSTOM_99,			-1, -1, FALSE,
    IMG_CUSTOM_99
  },
  {
    EL_CUSTOM_100,			-1, -1, FALSE,
    IMG_CUSTOM_100
  },
  {
    EL_CUSTOM_101,			-1, -1, FALSE,
    IMG_CUSTOM_101
  },
  {
    EL_CUSTOM_102,			-1, -1, FALSE,
    IMG_CUSTOM_102
  },
  {
    EL_CUSTOM_103,			-1, -1, FALSE,
    IMG_CUSTOM_103
  },
  {
    EL_CUSTOM_104,			-1, -1, FALSE,
    IMG_CUSTOM_104
  },
  {
    EL_CUSTOM_105,			-1, -1, FALSE,
    IMG_CUSTOM_105
  },
  {
    EL_CUSTOM_106,			-1, -1, FALSE,
    IMG_CUSTOM_106
  },
  {
    EL_CUSTOM_107,			-1, -1, FALSE,
    IMG_CUSTOM_107
  },
  {
    EL_CUSTOM_108,			-1, -1, FALSE,
    IMG_CUSTOM_108
  },
  {
    EL_CUSTOM_109,			-1, -1, FALSE,
    IMG_CUSTOM_109
  },
  {
    EL_CUSTOM_110,			-1, -1, FALSE,
    IMG_CUSTOM_110
  },
  {
    EL_CUSTOM_111,			-1, -1, FALSE,
    IMG_CUSTOM_111
  },
  {
    EL_CUSTOM_112,			-1, -1, FALSE,
    IMG_CUSTOM_112
  },
  {
    EL_CUSTOM_113,			-1, -1, FALSE,
    IMG_CUSTOM_113
  },
  {
    EL_CUSTOM_114,			-1, -1, FALSE,
    IMG_CUSTOM_114
  },
  {
    EL_CUSTOM_115,			-1, -1, FALSE,
    IMG_CUSTOM_115
  },
  {
    EL_CUSTOM_116,			-1, -1, FALSE,
    IMG_CUSTOM_116
  },
  {
    EL_CUSTOM_117,			-1, -1, FALSE,
    IMG_CUSTOM_117
  },
  {
    EL_CUSTOM_118,			-1, -1, FALSE,
    IMG_CUSTOM_118
  },
  {
    EL_CUSTOM_119,			-1, -1, FALSE,
    IMG_CUSTOM_119
  },
  {
    EL_CUSTOM_120,			-1, -1, FALSE,
    IMG_CUSTOM_120
  },
  {
    EL_CUSTOM_121,			-1, -1, FALSE,
    IMG_CUSTOM_121
  },
  {
    EL_CUSTOM_122,			-1, -1, FALSE,
    IMG_CUSTOM_122
  },
  {
    EL_CUSTOM_123,			-1, -1, FALSE,
    IMG_CUSTOM_123
  },
  {
    EL_CUSTOM_124,			-1, -1, FALSE,
    IMG_CUSTOM_124
  },
  {
    EL_CUSTOM_125,			-1, -1, FALSE,
    IMG_CUSTOM_125
  },
  {
    EL_CUSTOM_126,			-1, -1, FALSE,
    IMG_CUSTOM_126
  },
  {
    EL_CUSTOM_127,			-1, -1, FALSE,
    IMG_CUSTOM_127
  },
  {
    EL_CUSTOM_128,			-1, -1, FALSE,
    IMG_CUSTOM_128
  },
  {
    EL_CUSTOM_129,			-1, -1, FALSE,
    IMG_CUSTOM_129
  },
  {
    EL_CUSTOM_130,			-1, -1, FALSE,
    IMG_CUSTOM_130
  },
  {
    EL_CUSTOM_131,			-1, -1, FALSE,
    IMG_CUSTOM_131
  },
  {
    EL_CUSTOM_132,			-1, -1, FALSE,
    IMG_CUSTOM_132
  },
  {
    EL_CUSTOM_133,			-1, -1, FALSE,
    IMG_CUSTOM_133
  },
  {
    EL_CUSTOM_134,			-1, -1, FALSE,
    IMG_CUSTOM_134
  },
  {
    EL_CUSTOM_135,			-1, -1, FALSE,
    IMG_CUSTOM_135
  },
  {
    EL_CUSTOM_136,			-1, -1, FALSE,
    IMG_CUSTOM_136
  },
  {
    EL_CUSTOM_137,			-1, -1, FALSE,
    IMG_CUSTOM_137
  },
  {
    EL_CUSTOM_138,			-1, -1, FALSE,
    IMG_CUSTOM_138
  },
  {
    EL_CUSTOM_139,			-1, -1, FALSE,
    IMG_CUSTOM_139
  },
  {
    EL_CUSTOM_140,			-1, -1, FALSE,
    IMG_CUSTOM_140
  },
  {
    EL_CUSTOM_141,			-1, -1, FALSE,
    IMG_CUSTOM_141
  },
  {
    EL_CUSTOM_142,			-1, -1, FALSE,
    IMG_CUSTOM_142
  },
  {
    EL_CUSTOM_143,			-1, -1, FALSE,
    IMG_CUSTOM_143
  },
  {
    EL_CUSTOM_144,			-1, -1, FALSE,
    IMG_CUSTOM_144
  },
  {
    EL_CUSTOM_145,			-1, -1, FALSE,
    IMG_CUSTOM_145
  },
  {
    EL_CUSTOM_146,			-1, -1, FALSE,
    IMG_CUSTOM_146
  },
  {
    EL_CUSTOM_147,			-1, -1, FALSE,
    IMG_CUSTOM_147
  },
  {
    EL_CUSTOM_148,			-1, -1, FALSE,
    IMG_CUSTOM_148
  },
  {
    EL_CUSTOM_149,			-1, -1, FALSE,
    IMG_CUSTOM_149
  },
  {
    EL_CUSTOM_150,			-1, -1, FALSE,
    IMG_CUSTOM_150
  },
  {
    EL_CUSTOM_151,			-1, -1, FALSE,
    IMG_CUSTOM_151
  },
  {
    EL_CUSTOM_152,			-1, -1, FALSE,
    IMG_CUSTOM_152
  },
  {
    EL_CUSTOM_153,			-1, -1, FALSE,
    IMG_CUSTOM_153
  },
  {
    EL_CUSTOM_154,			-1, -1, FALSE,
    IMG_CUSTOM_154
  },
  {
    EL_CUSTOM_155,			-1, -1, FALSE,
    IMG_CUSTOM_155
  },
  {
    EL_CUSTOM_156,			-1, -1, FALSE,
    IMG_CUSTOM_156
  },
  {
    EL_CUSTOM_157,			-1, -1, FALSE,
    IMG_CUSTOM_157
  },
  {
    EL_CUSTOM_158,			-1, -1, FALSE,
    IMG_CUSTOM_158
  },
  {
    EL_CUSTOM_159,			-1, -1, FALSE,
    IMG_CUSTOM_159
  },
  {
    EL_CUSTOM_160,			-1, -1, FALSE,
    IMG_CUSTOM_160
  },
  {
    EL_CUSTOM_161,			-1, -1, FALSE,
    IMG_CUSTOM_161
  },
  {
    EL_CUSTOM_162,			-1, -1, FALSE,
    IMG_CUSTOM_162
  },
  {
    EL_CUSTOM_163,			-1, -1, FALSE,
    IMG_CUSTOM_163
  },
  {
    EL_CUSTOM_164,			-1, -1, FALSE,
    IMG_CUSTOM_164
  },
  {
    EL_CUSTOM_165,			-1, -1, FALSE,
    IMG_CUSTOM_165
  },
  {
    EL_CUSTOM_166,			-1, -1, FALSE,
    IMG_CUSTOM_166
  },
  {
    EL_CUSTOM_167,			-1, -1, FALSE,
    IMG_CUSTOM_167
  },
  {
    EL_CUSTOM_168,			-1, -1, FALSE,
    IMG_CUSTOM_168
  },
  {
    EL_CUSTOM_169,			-1, -1, FALSE,
    IMG_CUSTOM_169
  },
  {
    EL_CUSTOM_170,			-1, -1, FALSE,
    IMG_CUSTOM_170
  },
  {
    EL_CUSTOM_171,			-1, -1, FALSE,
    IMG_CUSTOM_171
  },
  {
    EL_CUSTOM_172,			-1, -1, FALSE,
    IMG_CUSTOM_172
  },
  {
    EL_CUSTOM_173,			-1, -1, FALSE,
    IMG_CUSTOM_173
  },
  {
    EL_CUSTOM_174,			-1, -1, FALSE,
    IMG_CUSTOM_174
  },
  {
    EL_CUSTOM_175,			-1, -1, FALSE,
    IMG_CUSTOM_175
  },
  {
    EL_CUSTOM_176,			-1, -1, FALSE,
    IMG_CUSTOM_176
  },
  {
    EL_CUSTOM_177,			-1, -1, FALSE,
    IMG_CUSTOM_177
  },
  {
    EL_CUSTOM_178,			-1, -1, FALSE,
    IMG_CUSTOM_178
  },
  {
    EL_CUSTOM_179,			-1, -1, FALSE,
    IMG_CUSTOM_179
  },
  {
    EL_CUSTOM_180,			-1, -1, FALSE,
    IMG_CUSTOM_180
  },
  {
    EL_CUSTOM_181,			-1, -1, FALSE,
    IMG_CUSTOM_181
  },
  {
    EL_CUSTOM_182,			-1, -1, FALSE,
    IMG_CUSTOM_182
  },
  {
    EL_CUSTOM_183,			-1, -1, FALSE,
    IMG_CUSTOM_183
  },
  {
    EL_CUSTOM_184,			-1, -1, FALSE,
    IMG_CUSTOM_184
  },
  {
    EL_CUSTOM_185,			-1, -1, FALSE,
    IMG_CUSTOM_185
  },
  {
    EL_CUSTOM_186,			-1, -1, FALSE,
    IMG_CUSTOM_186
  },
  {
    EL_CUSTOM_187,			-1, -1, FALSE,
    IMG_CUSTOM_187
  },
  {
    EL_CUSTOM_188,			-1, -1, FALSE,
    IMG_CUSTOM_188
  },
  {
    EL_CUSTOM_189,			-1, -1, FALSE,
    IMG_CUSTOM_189
  },
  {
    EL_CUSTOM_190,			-1, -1, FALSE,
    IMG_CUSTOM_190
  },
  {
    EL_CUSTOM_191,			-1, -1, FALSE,
    IMG_CUSTOM_191
  },
  {
    EL_CUSTOM_192,			-1, -1, FALSE,
    IMG_CUSTOM_192
  },
  {
    EL_CUSTOM_193,			-1, -1, FALSE,
    IMG_CUSTOM_193
  },
  {
    EL_CUSTOM_194,			-1, -1, FALSE,
    IMG_CUSTOM_194
  },
  {
    EL_CUSTOM_195,			-1, -1, FALSE,
    IMG_CUSTOM_195
  },
  {
    EL_CUSTOM_196,			-1, -1, FALSE,
    IMG_CUSTOM_196
  },
  {
    EL_CUSTOM_197,			-1, -1, FALSE,
    IMG_CUSTOM_197
  },
  {
    EL_CUSTOM_198,			-1, -1, FALSE,
    IMG_CUSTOM_198
  },
  {
    EL_CUSTOM_199,			-1, -1, FALSE,
    IMG_CUSTOM_199
  },
  {
    EL_CUSTOM_200,			-1, -1, FALSE,
    IMG_CUSTOM_200
  },
  {
    EL_CUSTOM_201,			-1, -1, FALSE,
    IMG_CUSTOM_201
  },
  {
    EL_CUSTOM_202,			-1, -1, FALSE,
    IMG_CUSTOM_202
  },
  {
    EL_CUSTOM_203,			-1, -1, FALSE,
    IMG_CUSTOM_203
  },
  {
    EL_CUSTOM_204,			-1, -1, FALSE,
    IMG_CUSTOM_204
  },
  {
    EL_CUSTOM_205,			-1, -1, FALSE,
    IMG_CUSTOM_205
  },
  {
    EL_CUSTOM_206,			-1, -1, FALSE,
    IMG_CUSTOM_206
  },
  {
    EL_CUSTOM_207,			-1, -1, FALSE,
    IMG_CUSTOM_207
  },
  {
    EL_CUSTOM_208,			-1, -1, FALSE,
    IMG_CUSTOM_208
  },
  {
    EL_CUSTOM_209,			-1, -1, FALSE,
    IMG_CUSTOM_209
  },
  {
    EL_CUSTOM_210,			-1, -1, FALSE,
    IMG_CUSTOM_210
  },
  {
    EL_CUSTOM_211,			-1, -1, FALSE,
    IMG_CUSTOM_211
  },
  {
    EL_CUSTOM_212,			-1, -1, FALSE,
    IMG_CUSTOM_212
  },
  {
    EL_CUSTOM_213,			-1, -1, FALSE,
    IMG_CUSTOM_213
  },
  {
    EL_CUSTOM_214,			-1, -1, FALSE,
    IMG_CUSTOM_214
  },
  {
    EL_CUSTOM_215,			-1, -1, FALSE,
    IMG_CUSTOM_215
  },
  {
    EL_CUSTOM_216,			-1, -1, FALSE,
    IMG_CUSTOM_216
  },
  {
    EL_CUSTOM_217,			-1, -1, FALSE,
    IMG_CUSTOM_217
  },
  {
    EL_CUSTOM_218,			-1, -1, FALSE,
    IMG_CUSTOM_218
  },
  {
    EL_CUSTOM_219,			-1, -1, FALSE,
    IMG_CUSTOM_219
  },
  {
    EL_CUSTOM_220,			-1, -1, FALSE,
    IMG_CUSTOM_220
  },
  {
    EL_CUSTOM_221,			-1, -1, FALSE,
    IMG_CUSTOM_221
  },
  {
    EL_CUSTOM_222,			-1, -1, FALSE,
    IMG_CUSTOM_222
  },
  {
    EL_CUSTOM_223,			-1, -1, FALSE,
    IMG_CUSTOM_223
  },
  {
    EL_CUSTOM_224,			-1, -1, FALSE,
    IMG_CUSTOM_224
  },
  {
    EL_CUSTOM_225,			-1, -1, FALSE,
    IMG_CUSTOM_225
  },
  {
    EL_CUSTOM_226,			-1, -1, FALSE,
    IMG_CUSTOM_226
  },
  {
    EL_CUSTOM_227,			-1, -1, FALSE,
    IMG_CUSTOM_227
  },
  {
    EL_CUSTOM_228,			-1, -1, FALSE,
    IMG_CUSTOM_228
  },
  {
    EL_CUSTOM_229,			-1, -1, FALSE,
    IMG_CUSTOM_229
  },
  {
    EL_CUSTOM_230,			-1, -1, FALSE,
    IMG_CUSTOM_230
  },
  {
    EL_CUSTOM_231,			-1, -1, FALSE,
    IMG_CUSTOM_231
  },
  {
    EL_CUSTOM_232,			-1, -1, FALSE,
    IMG_CUSTOM_232
  },
  {
    EL_CUSTOM_233,			-1, -1, FALSE,
    IMG_CUSTOM_233
  },
  {
    EL_CUSTOM_234,			-1, -1, FALSE,
    IMG_CUSTOM_234
  },
  {
    EL_CUSTOM_235,			-1, -1, FALSE,
    IMG_CUSTOM_235
  },
  {
    EL_CUSTOM_236,			-1, -1, FALSE,
    IMG_CUSTOM_236
  },
  {
    EL_CUSTOM_237,			-1, -1, FALSE,
    IMG_CUSTOM_237
  },
  {
    EL_CUSTOM_238,			-1, -1, FALSE,
    IMG_CUSTOM_238
  },
  {
    EL_CUSTOM_239,			-1, -1, FALSE,
    IMG_CUSTOM_239
  },
  {
    EL_CUSTOM_240,			-1, -1, FALSE,
    IMG_CUSTOM_240
  },
  {
    EL_CUSTOM_241,			-1, -1, FALSE,
    IMG_CUSTOM_241
  },
  {
    EL_CUSTOM_242,			-1, -1, FALSE,
    IMG_CUSTOM_242
  },
  {
    EL_CUSTOM_243,			-1, -1, FALSE,
    IMG_CUSTOM_243
  },
  {
    EL_CUSTOM_244,			-1, -1, FALSE,
    IMG_CUSTOM_244
  },
  {
    EL_CUSTOM_245,			-1, -1, FALSE,
    IMG_CUSTOM_245
  },
  {
    EL_CUSTOM_246,			-1, -1, FALSE,
    IMG_CUSTOM_246
  },
  {
    EL_CUSTOM_247,			-1, -1, FALSE,
    IMG_CUSTOM_247
  },
  {
    EL_CUSTOM_248,			-1, -1, FALSE,
    IMG_CUSTOM_248
  },
  {
    EL_CUSTOM_249,			-1, -1, FALSE,
    IMG_CUSTOM_249
  },
  {
    EL_CUSTOM_250,			-1, -1, FALSE,
    IMG_CUSTOM_250
  },
  {
    EL_CUSTOM_251,			-1, -1, FALSE,
    IMG_CUSTOM_251
  },
  {
    EL_CUSTOM_252,			-1, -1, FALSE,
    IMG_CUSTOM_252
  },
  {
    EL_CUSTOM_253,			-1, -1, FALSE,
    IMG_CUSTOM_253
  },
  {
    EL_CUSTOM_254,			-1, -1, FALSE,
    IMG_CUSTOM_254
  },
  {
    EL_CUSTOM_255,			-1, -1, FALSE,
    IMG_CUSTOM_255
  },
  {
    EL_CUSTOM_256,			-1, -1, FALSE,
    IMG_CUSTOM_256
  },
  {
    EL_GROUP_1,				-1, -1, FALSE,
    IMG_GROUP_1
  },
  {
    EL_GROUP_2,				-1, -1, FALSE,
    IMG_GROUP_2
  },
  {
    EL_GROUP_3,				-1, -1, FALSE,
    IMG_GROUP_3
  },
  {
    EL_GROUP_4,				-1, -1, FALSE,
    IMG_GROUP_4
  },
  {
    EL_GROUP_5,				-1, -1, FALSE,
    IMG_GROUP_5
  },
  {
    EL_GROUP_6,				-1, -1, FALSE,
    IMG_GROUP_6
  },
  {
    EL_GROUP_7,				-1, -1, FALSE,
    IMG_GROUP_7
  },
  {
    EL_GROUP_8,				-1, -1, FALSE,
    IMG_GROUP_8
  },
  {
    EL_GROUP_9,				-1, -1, FALSE,
    IMG_GROUP_9
  },
  {
    EL_GROUP_10,			-1, -1, FALSE,
    IMG_GROUP_10
  },
  {
    EL_GROUP_11,			-1, -1, FALSE,
    IMG_GROUP_11
  },
  {
    EL_GROUP_12,			-1, -1, FALSE,
    IMG_GROUP_12
  },
  {
    EL_GROUP_13,			-1, -1, FALSE,
    IMG_GROUP_13
  },
  {
    EL_GROUP_14,			-1, -1, FALSE,
    IMG_GROUP_14
  },
  {
    EL_GROUP_15,			-1, -1, FALSE,
    IMG_GROUP_15
  },
  {
    EL_GROUP_16,			-1, -1, FALSE,
    IMG_GROUP_16
  },
  {
    EL_GROUP_17,			-1, -1, FALSE,
    IMG_GROUP_17
  },
  {
    EL_GROUP_18,			-1, -1, FALSE,
    IMG_GROUP_18
  },
  {
    EL_GROUP_19,			-1, -1, FALSE,
    IMG_GROUP_19
  },
  {
    EL_GROUP_20,			-1, -1, FALSE,
    IMG_GROUP_20
  },
  {
    EL_GROUP_21,			-1, -1, FALSE,
    IMG_GROUP_21
  },
  {
    EL_GROUP_22,			-1, -1, FALSE,
    IMG_GROUP_22
  },
  {
    EL_GROUP_23,			-1, -1, FALSE,
    IMG_GROUP_23
  },
  {
    EL_GROUP_24,			-1, -1, FALSE,
    IMG_GROUP_24
  },
  {
    EL_GROUP_25,			-1, -1, FALSE,
    IMG_GROUP_25
  },
  {
    EL_GROUP_26,			-1, -1, FALSE,
    IMG_GROUP_26
  },
  {
    EL_GROUP_27,			-1, -1, FALSE,
    IMG_GROUP_27
  },
  {
    EL_GROUP_28,			-1, -1, FALSE,
    IMG_GROUP_28
  },
  {
    EL_GROUP_29,			-1, -1, FALSE,
    IMG_GROUP_29
  },
  {
    EL_GROUP_30,			-1, -1, FALSE,
    IMG_GROUP_30
  },
  {
    EL_GROUP_31,			-1, -1, FALSE,
    IMG_GROUP_31
  },
  {
    EL_GROUP_32,			-1, -1, FALSE,
    IMG_GROUP_32
  },
  {
    -1,					-1, -1, FALSE,
    -1
  },
};

#endif	/* CONF_E2G_C */
